@@ -15,9 +15,10 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include <linux/version.h>
 #include <linux/miscdevice.h>
 #include <linux/module.h>
 #include <linux/init.h>
@@ -34,6 +35,13 @@ MODULE_AUTHOR("Ivan Hu");
 MODULE_DESCRIPTION("EFI Runtime Driver");
 MODULE_LICENSE("GPL");
 
+/* commit 83e681897 turned efi_enabled into a function, so abstract it */
+#ifdef EFI_RUNTIME_SERVICES
+#define EFI_RUNTIME_ENABLED	efi_enabled(EFI_RUNTIME_SERVICES)
+#else
+#define EFI_RUNTIME_ENABLED	efi_enabled
+#endif
+
 static void convert_from_efi_time(efi_time_t *eft, EFI_TIME *time)
 {
 	memset(time, 0, sizeof(EFI_TIME));
@@ -52,7 +60,7 @@ static void convert_from_efi_time(efi_time_t *eft, EFI_TIME *time)
 
 static void convert_to_efi_time(efi_time_t *eft, EFI_TIME *time)
 {
-	memset(eft, 0, sizeof(eft));
+	memset(eft, 0, sizeof(*eft));
 	eft->year = time->Year;
 	eft->month = time->Month;
 	eft->day = time->Day;
@@ -117,11 +125,11 @@ static long efi_runtime_ioctl(struct file *file, unsigned int cmd,
 	struct efi_getnextvariablename __user *pgetnextvariablename;
 	unsigned long name_size;
 
-	struct efi_queryvariableinfo __user *pqueryvariableinfo;
-
 	struct efi_getnexthighmonotoniccount __user *pgetnexthighmonotoniccount;
-
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0)
+	struct efi_queryvariableinfo __user *pqueryvariableinfo;
 	struct efi_querycapsulecapabilities __user *pquerycapsulecapabilities;
+#endif
 
 	switch (cmd) {
 	case EFI_RUNTIME_GET_VARIABLE:
@@ -268,6 +276,7 @@ static long efi_runtime_ioctl(struct file *file, unsigned int cmd,
 			return -EINVAL;
 		return 0;
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0)
 	case EFI_RUNTIME_QUERY_VARIABLEINFO:
 
 		pqueryvariableinfo = (struct efi_queryvariableinfo __user *)arg;
@@ -285,6 +294,7 @@ static long efi_runtime_ioctl(struct file *file, unsigned int cmd,
 			return -EINVAL;
 
 		return 0;
+#endif
 
 	case EFI_RUNTIME_GET_NEXTHIGHMONOTONICCOUNT:
 
@@ -300,6 +310,7 @@ static long efi_runtime_ioctl(struct file *file, unsigned int cmd,
 
 		return 0;
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0)
 	case EFI_RUNTIME_QUERY_CAPSULECAPABILITIES:
 
 		pquerycapsulecapabilities = (struct
@@ -318,6 +329,7 @@ static long efi_runtime_ioctl(struct file *file, unsigned int cmd,
 			return -EINVAL;
 
 		return 0;
+#endif
 	}
 
 	return -ENOTTY;
@@ -361,8 +373,10 @@ static int __init efi_runtime_init(void)
 
 	printk(KERN_INFO "EFI_RUNTIME Driver v%s\n", EFI_FWTS_EFI_VERSION);
 
-	if (!efi_enabled)
+	if (!EFI_RUNTIME_ENABLED) {
+		printk(KERN_INFO "EFI runtime services not enabled.\n");
 		return -ENODEV;
+	}
 
 	ret = misc_register(&efi_runtime_dev);
 	if (ret) {
