@@ -76,12 +76,15 @@ static fwts_list *get_fan_info(fwts_framework *fw)
 			if (info == NULL) {
 				fwts_log_error(fw, "Out of memory gathing fan information.");
 				fwts_list_free(fans, free_fan_info);
+				closedir(dir);
 				return NULL;
 			}
 
 			if ((info->name = strdup(entry->d_name)) == NULL) {
 				fwts_log_error(fw, "Out of memory gathing fan information.");
 				fwts_list_free(fans, free_fan_info);
+				free(info);
+				closedir(dir);
 				return NULL;
 			}
 
@@ -213,13 +216,13 @@ static int fan_test2(fwts_framework *fw)
 							info1->name, info1->cur_state, info2->cur_state);
 							changed = true;
 					}
-					if (info2->cur_state > info2->cur_state) {
+					if (info2->cur_state > info1->cur_state) {
 						fwts_passed(fw, "Fan %s current state increased from %d to %d "
 							"while CPUs were busy.",
 							info1->name, info1->cur_state, info2->cur_state);
 							changed = true;
 					}
-					if (info2->cur_state == info2->cur_state)
+					if (info2->cur_state == info1->cur_state)
 						fwts_log_info(fw, "Fan %s current state did not change from value %d "
 							"while CPUs were busy.",
 							info1->name, info1->cur_state);
