@@ -114,6 +114,7 @@ static int lid_test_state(fwts_framework *fw, int button)
 
 	if ((fd = fwts_acpi_event_open()) < 0) {
 		fwts_log_error(fw, "Cannot connect to acpid.");
+		fwts_gpe_free(gpes_start, gpe_count);
 		return FWTS_ERROR;
 	}
 
@@ -132,6 +133,8 @@ static int lid_test_state(fwts_framework *fw, int button)
 
 	if ((gpe_count = fwts_gpe_read(&gpes_end)) == FWTS_ERROR) {
 		fwts_log_error(fw, "Cannot read GPEs.");
+		fwts_gpe_free(gpes_start, gpe_count);
+		return FWTS_ERROR;
 	}
 
 	fwts_gpe_test(fw, gpes_start, gpes_end, gpe_count);
@@ -143,7 +146,7 @@ static int lid_test_state(fwts_framework *fw, int button)
 			"Did not detect any ACPI LID events while waiting for to LID %s.", state);
 		fwts_tag_failed(fw, FWTS_TAG_ACPI_LID);
 		fwts_tag_failed(fw, FWTS_TAG_ACPI_EVENT);
-	} else
+	} else {
 		fwts_passed(fw, "Detected ACPI LID events while waiting for LID to %s.", state);
 		if ((matching == 0) || (not_matching > 0)) {
 			fwts_failed(fw, LOG_LEVEL_HIGH, "NoLidState",
@@ -151,6 +154,7 @@ static int lid_test_state(fwts_framework *fw, int button)
 			fwts_tag_failed(fw, FWTS_TAG_ACPI_LID);
 		} else
 			fwts_passed(fw, "Detected lid %s state.", state);
+	}
 
 	return FWTS_OK;
 }
