@@ -17,6 +17,8 @@
  *
  */
 
+#define _GNU_SOURCE
+
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
@@ -31,12 +33,9 @@
 #include <signal.h>
 #include <pthread.h>
 
-static pthread_mutex_t mutex_lock_sem_table;
-static pthread_mutex_t mutex_thread_info;
-
 #include "fwts.h"
 
-/* acpica headers */
+/* ACPICA specific headers */
 #include "acpi.h"
 #include "accommon.h"
 #include "acparser.h"
@@ -46,37 +45,26 @@ static pthread_mutex_t mutex_thread_info;
 #include "actables.h"
 #include "acinterp.h"
 #include "acapps.h"
-#include <pthread.h>
-#include <errno.h>
 
-#define ACPI_MAX_INIT_TABLES	(32)
-#define AEXEC_NUM_REGIONS   	(8)
+#define ACPI_MAX_INIT_TABLES		(64)	/* Number of ACPI tables */
 
-#define MAX_SEMAPHORES		(1024)
-#define MAX_THREADS		(128)
+#define MAX_SEMAPHORES			(1024)	/* For semaphore tracking */
+#define MAX_THREADS			(128)	/* For thread tracking */
 
-#define MAX_WAIT_TIMEOUT	(20)	/* Seconds */
+#define MAX_WAIT_TIMEOUT		(20)	/* Seconds */
 
+#define ACPI_ADR_SPACE_USER_DEFINED1	(0x80)
+#define ACPI_ADR_SPACE_USER_DEFINED2	(0xE4)
+
+/* 
+ *  Semaphore accounting info
+ */
 typedef struct {
 	sem_t		sem;	/* Semaphore handle */
 	int		count;	/* count > 0 if acquired */
 	bool		used;	/* Semaphore being used flag */
 } sem_info;
 
-typedef void * (*PTHREAD_CALLBACK)(void *);
-
-BOOLEAN AcpiGbl_IgnoreErrors = FALSE;
-UINT8   AcpiGbl_RegionFillValue = 0;
-
-/*
- *  Used to account for semaphores used by AcpiOs*Semaphore()
- */
-static sem_info			sem_table[MAX_SEMAPHORES];
-
-static ACPI_TABLE_DESC		Tables[ACPI_MAX_INIT_TABLES];
-
-static bool			region_handler_called;
-
 /*
  *  Used to account for threads used by AcpiOsExecute
  */
@@ -85,7 +73,19 @@ typedef struct {
 	pthread_t	thread;	/* thread info */
 } fwts_thread;
 
-static fwts_thread	threads[MAX_THREADS];
+typedef void * (*pthread_callback)(void *);
+
+BOOLEAN AcpiGbl_IgnoreErrors = FALSE;
+UINT8   AcpiGbl_RegionFillValue = 0;
+
+static ACPI_TABLE_DESC		Tables[ACPI_MAX_INIT_TABLES];	/* ACPICA Table descriptors */
+static bool			region_handler_called;		/* Region handler tracking */
+
+static sem_info			sem_table[MAX_SEMAPHORES];	/* Semaphore accounting for AcpiOs*Semaphore() */
+static pthread_mutex_t		mutex_lock_sem_table;		/* Semaphore accounting mutex */
+
+static fwts_thread		threads[MAX_THREADS];		/* Thread accounting for AcpiOsExecute */
+static pthread_mutex_t		mutex_thread_info;		/* Thread accounting mutex */
 
 /*
  *  Static copies of ACPI tables used by ACPICA execution engine
@@ -96,28 +96,8 @@ static ACPI_TABLE_RSDP		*fwts_acpica_RSDP;
 static ACPI_TABLE_FADT		*fwts_acpica_FADT;
 static void 			*fwts_acpica_DSDT;
 
-static fwts_framework		*fwts_acpica_fw;			/* acpica context copy of fw */
-static bool			fwts_acpica_init_called;		/* > 0, ACPICA initialised */
-static fwts_acpica_log_callback fwts_acpica_log_callback_func = NULL;	/* logging call back func */
-
-#define ACPI_ADR_SPACE_USER_DEFINED1        0x80
-#define ACPI_ADR_SPACE_USER_DEFINED2        0xE4
-
-static ACPI_ADR_SPACE_TYPE fwts_space_id_list[] =
-{
-	ACPI_ADR_SPACE_SYSTEM_MEMORY,
-	ACPI_ADR_SPACE_SYSTEM_IO,
-	ACPI_ADR_SPACE_EC,
-	ACPI_ADR_SPACE_SMBUS,
-	ACPI_ADR_SPACE_CMOS,
-	ACPI_ADR_SPACE_GSBUS,
-	ACPI_ADR_SPACE_GPIO,
-	ACPI_ADR_SPACE_PCI_BAR_TARGET,
-	ACPI_ADR_SPACE_IPMI,
-	ACPI_ADR_SPACE_FIXED_HARDWARE,
-	ACPI_ADR_SPACE_USER_DEFINED1,
-	ACPI_ADR_SPACE_USER_DEFINED2
-};
+static fwts_framework		*fwts_acpica_fw;		/* acpica context copy of fw */
+static bool			fwts_acpica_init_called;	/* > 0, ACPICA initialised */
 
 /* Semaphore Tracking */
 
@@ -229,6 +209,15 @@ static ACPI_STATUS fwts_exception_handler(
 			"ACPICA Exception %s during execution at module level (table load)",
 			exception);
 
+	if (AcpiGbl_IgnoreErrors) {
+		if (AmlStatus != AE_OK) {
+			fwts_log_info(fwts_acpica_fw,
+				"ACPICA Exception override, forcing AE_OK for execption %s",
+				exception);
+			AmlStatus = AE_OK;
+		}
+	}
+
 	return AmlStatus;
 }
 
@@ -404,25 +393,6 @@ ACPI_PHYSICAL_ADDRESS AeLocalGetRootPointer(void)
 	return (ACPI_PHYSICAL_ADDRESS)fwts_acpica_RSDP;
 }
 
-/*
- *  fwts_acpica_set_log_callback()
- *	define logging callback function as used by fwts_acpica_vprintf()
- */
-void fwts_acpica_set_log_callback(fwts_framework *fw, fwts_acpica_log_callback func)
-{
-	fwts_acpica_log_callback_func = func;
-}
-
-/*
- *  fwts_acpica_debug_command()
- *	run a debugging command, requires a logging callback function (or set to NULL for none).
- */
-void fwts_acpica_debug_command(fwts_framework *fw, fwts_acpica_log_callback func, char *command)
-{
-	fwts_acpica_set_log_callback(fw, func);
-	AcpiDbCommandDispatch(command, NULL, NULL);
-}
-
 /*
  *  fwts_acpica_vprintf()
  *	accumulate prints from ACPICA engine, emit them when we hit terminal '\n'
@@ -432,10 +402,21 @@ void fwts_acpica_vprintf(const char *fmt, va_list args)
 	static char *buffer;
 	static size_t buffer_len;
 
-	char tmp[4096];
+	char *tmp;
 	size_t tmp_len;
 
-	vsnprintf(tmp, sizeof(tmp), fmt, args);
+	if (fwts_acpica_fw == NULL)
+		return;
+
+	/* Only emit messages if in ACPICA debug mode */
+	if (!(fwts_acpica_fw->flags & FWTS_FLAG_ACPICA_DEBUG))
+		return;
+
+	if (vasprintf(&tmp, fmt, args) < 0) {
+		fwts_log_info(fwts_acpica_fw, "Out of memory allocating ACPICA printf buffer.");
+		return;
+	}
+
 	tmp_len = strlen(tmp);
 
 	if (buffer_len == 0) {
@@ -455,11 +436,12 @@ void fwts_acpica_vprintf(const char *fmt, va_list args)
 	}
 
 	if (index(buffer, '\n') != NULL) {
-		if (fwts_acpica_log_callback_func)
-			fwts_acpica_log_callback_func(fwts_acpica_fw, buffer);
+		fwts_log_info(fwts_acpica_fw, "%s", buffer);
 		free(buffer);
 		buffer_len = 0;
 	}
+
+	free(tmp);
 }
 
 /*
@@ -509,8 +491,10 @@ ACPI_STATUS AcpiOsCreateSemaphore(UINT32 MaxUnits,
 		}
 	}
 
-	if (!sem)
+	if (!sem) {
+		pthread_mutex_unlock(&mutex_lock_sem_table);
 		return AE_NO_MEMORY;
+	}
 
 	sem->used = true;
 	sem->count = 0;
@@ -585,6 +569,7 @@ ACPI_STATUS AcpiOsWaitSemaphore(ACPI_HANDLE handle, UINT32 Units, UINT16 Timeout
 		 *  control to continue.  It is evil.
 		 */
 		sa.sa_handler = sem_alarm;
+		sigemptyset(&sa.sa_mask);
 		sa.sa_flags = 0;
 		sigaction(SIGALRM, &sa, NULL);
 		alarm(MAX_WAIT_TIMEOUT);
@@ -664,7 +649,7 @@ ACPI_STATUS AcpiOsReadPort(ACPI_IO_ADDRESS addr, UINT32 *value, UINT32 width)
 }
 
 typedef struct {
-	PTHREAD_CALLBACK	func;
+	pthread_callback	func;
 	void *			context;
 	int			thread_index;
 } fwts_func_wrapper_context;
@@ -710,13 +695,13 @@ ACPI_STATUS AcpiOsExecute(
 				return AE_NO_MEMORY;
 			}
 
-			ctx->func = (PTHREAD_CALLBACK)function;
+			ctx->func = (pthread_callback)function;
 			ctx->context = func_context;
 			ctx->thread_index = i;
 			threads[i].used = true;
 
 			ret = pthread_create(&threads[i].thread, NULL,
-				(PTHREAD_CALLBACK)fwts_pthread_func_wrapper, ctx);
+				(pthread_callback)fwts_pthread_func_wrapper, ctx);
 			pthread_mutex_unlock(&mutex_thread_info);
 
 			if (ret)
@@ -784,6 +769,22 @@ int fwtsInstallEarlyHandlers(fwts_framework *fw)
 	int i;
 	ACPI_HANDLE	handle;
 
+	static ACPI_ADR_SPACE_TYPE fwts_space_id_list[] =
+	{
+		ACPI_ADR_SPACE_SYSTEM_MEMORY,
+		ACPI_ADR_SPACE_SYSTEM_IO,
+		ACPI_ADR_SPACE_EC,
+		ACPI_ADR_SPACE_SMBUS,
+		ACPI_ADR_SPACE_CMOS,
+		ACPI_ADR_SPACE_GSBUS,
+		ACPI_ADR_SPACE_GPIO,
+		ACPI_ADR_SPACE_PCI_BAR_TARGET,
+		ACPI_ADR_SPACE_IPMI,
+		ACPI_ADR_SPACE_FIXED_HARDWARE,
+		ACPI_ADR_SPACE_USER_DEFINED1,
+		ACPI_ADR_SPACE_USER_DEFINED2
+	};
+
 	if (AcpiInstallInterfaceHandler(fwts_interface_handler) != AE_OK) {
 		fwts_log_error(fw, "Failed to install interface handler.");
 		return FWTS_ERROR;
@@ -875,6 +876,17 @@ int fwtsInstallEarlyHandlers(fwts_framework *fw)
 	return FWTS_OK;
 }
 
+/*
+ *  fwts_acpcia_set_fwts_framework()
+ *	set fwts_acpica_fw ptr
+ */
+void fwts_acpcia_set_fwts_framework(fwts_framework *fw)
+{
+	fwts_acpica_fw = fw;
+}
+
+#define FWTS_ACPICA_MODE(fw, mode)	\
+	(((fw->acpica_mode & mode) == mode) ? 1 : 0)
 
 /*
  *  fwts_acpica_init()
@@ -891,17 +903,25 @@ int fwts_acpica_init(fwts_framework *fw)
 	if (fwts_acpica_init_called)
 		return FWTS_ERROR;
 
+	AcpiGbl_AllMethodsSerialized =
+		FWTS_ACPICA_MODE(fw, FWTS_ACPICA_MODE_SERIALIZED);
+	AcpiGbl_EnableInterpreterSlack =
+		FWTS_ACPICA_MODE(fw, FWTS_ACPICA_MODE_SLACK);
+	AcpiGbl_IgnoreErrors =
+		FWTS_ACPICA_MODE(fw, FWTS_ACPICA_MODE_IGNORE_ERRORS);
+	AcpiGbl_DisableAutoRepair =
+		FWTS_ACPICA_MODE(fw, FWTS_ACPICA_MODE_DISABLE_AUTO_REPAIR);
+
 	pthread_mutex_init(&mutex_lock_sem_table, NULL);
 	pthread_mutex_init(&mutex_thread_info, NULL);
 
-	fwts_acpica_fw = fw;
+	fwts_acpcia_set_fwts_framework(fw);
 
 	AcpiDbgLevel = ACPI_NORMAL_DEFAULT;
 	AcpiDbgLayer = 0x00000000;
 
 	AcpiOsRedirectOutput(stderr);
 
-
 	if (ACPI_FAILURE(AcpiInitializeSubsystem())) {
 		fwts_log_error(fw, "Failed to initialise ACPICA subsystem.");
 		return FWTS_ERROR;
@@ -1065,10 +1085,7 @@ int fwts_acpica_init(fwts_framework *fw)
 }
 
 #define FWTS_ACPICA_FREE(x)	\
-	if (x) {		\
-		fwts_low_free(x);	\
-		x = NULL;	\
-	}			\
+	{ fwts_low_free(x); x = NULL; }
 
 /*
  *  fwts_acpica_deinit()
