@@ -8,13 +8,13 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2012, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
  *
  * 2.1. This is your license from Intel Corp. under its intellectual property
- * rights.  You may have additional license terms from the party that provided
+ * rights. You may have additional license terms from the party that provided
  * you this software, covering your right to use that party's intellectual
  * property rights.
  *
@@ -31,7 +31,7 @@
  * offer to sell, and import the Covered Code and derivative works thereof
  * solely to the minimum extent necessary to exercise the above copyright
  * license, and in no event shall the patent license extend to any additions
- * to or modifications of the Original Intel Code.  No other license or right
+ * to or modifications of the Original Intel Code. No other license or right
  * is granted directly or by implication, estoppel or otherwise;
  *
  * The above copyright and patent license is granted only if the following
@@ -43,11 +43,11 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification with rights to further distribute source must include
  * the above Copyright Notice, the above License, this list of Conditions,
- * and the following Disclaimer and Export Compliance provision.  In addition,
+ * and the following Disclaimer and Export Compliance provision. In addition,
  * Licensee must cause all Covered Code to which Licensee contributes to
  * contain a file documenting the changes Licensee made to create that Covered
- * Code and the date of any change.  Licensee must include in that file the
- * documentation of any changes made by any predecessor Licensee.  Licensee
+ * Code and the date of any change. Licensee must include in that file the
+ * documentation of any changes made by any predecessor Licensee. Licensee
  * must include a prominent statement that the modification is derived,
  * directly or indirectly, from Original Intel Code.
  *
@@ -55,7 +55,7 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification without rights to further distribute source must
  * include the following Disclaimer and Export Compliance provision in the
- * documentation and/or other materials provided with distribution.  In
+ * documentation and/or other materials provided with distribution. In
  * addition, Licensee may not authorize further sublicense of source of any
  * portion of the Covered Code, and must include terms to the effect that the
  * license from Licensee to its licensee is limited to the intellectual
@@ -80,10 +80,10 @@
  * 4. Disclaimer and Export Compliance
  *
  * 4.1. INTEL MAKES NO WARRANTY OF ANY KIND REGARDING ANY SOFTWARE PROVIDED
- * HERE.  ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
- * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT,  ASSISTANCE,
- * INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL WILL NOT PROVIDE ANY
- * UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY DISCLAIMS ANY
+ * HERE. ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
+ * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT, ASSISTANCE,
+ * INSTALLATION, TRAINING OR OTHER SERVICES. INTEL WILL NOT PROVIDE ANY
+ * UPDATES, ENHANCEMENTS OR EXTENSIONS. INTEL SPECIFICALLY DISCLAIMS ANY
  * IMPLIED WARRANTIES OF MERCHANTABILITY, NONINFRINGEMENT AND FITNESS FOR A
  * PARTICULAR PURPOSE.
  *
@@ -92,14 +92,14 @@
  * COSTS OF PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, OR FOR ANY INDIRECT,
  * SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS AGREEMENT, UNDER ANY
  * CAUSE OF ACTION OR THEORY OF LIABILITY, AND IRRESPECTIVE OF WHETHER INTEL
- * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES.  THESE LIMITATIONS
+ * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES. THESE LIMITATIONS
  * SHALL APPLY NOTWITHSTANDING THE FAILURE OF THE ESSENTIAL PURPOSE OF ANY
  * LIMITED REMEDY.
  *
  * 4.3. Licensee shall not export, either directly or indirectly, any of this
  * software or system incorporating such software without first obtaining any
  * required license or other approval from the U. S. Department of Commerce or
- * any other agency or department of the United States Government.  In the
+ * any other agency or department of the United States Government. In the
  * event Licensee exports any such software from the United States or
  * re-exports any such software from a foreign destination, Licensee shall
  * ensure that the distribution and export/re-export of the software is in
@@ -118,7 +118,6 @@
 #include "acparser.h"
 #include "amlcode.h"
 #include "acdisasm.h"
-#include "acnamesp.h"
 
 #ifdef ACPI_DISASSEMBLER
 
@@ -194,6 +193,7 @@ AcpiDmPredefinedDescription (
     switch (NameString[1])
     {
     case 'A':
+
         if ((NameString[2] == 'C') && (LastCharIsDigit))
         {
             NameString = "_ACx";
@@ -205,6 +205,7 @@ AcpiDmPredefinedDescription (
         break;
 
     case 'E':
+
         if ((NameString[2] == 'J') && (LastCharIsDigit))
         {
             NameString = "_EJx";
@@ -216,6 +217,7 @@ AcpiDmPredefinedDescription (
         break;
 
     case 'L':
+
         if (LastCharsAreHex)
         {
             NameString = "_Lxx";
@@ -223,6 +225,7 @@ AcpiDmPredefinedDescription (
         break;
 
     case 'Q':
+
         if (LastCharsAreHex)
         {
             NameString = "_Qxx";
@@ -230,6 +233,7 @@ AcpiDmPredefinedDescription (
         break;
 
     case 'T':
+
         if (NameString[2] == '_')
         {
             NameString = "_T_x";
@@ -237,6 +241,7 @@ AcpiDmPredefinedDescription (
         break;
 
     case 'W':
+
         if (LastCharsAreHex)
         {
             NameString = "_Wxx";
@@ -244,6 +249,7 @@ AcpiDmPredefinedDescription (
         break;
 
     default:
+
         break;
     }
 
@@ -609,21 +615,26 @@ AcpiDmDisassembleOneOp (
         return;
 
     case ACPI_DASM_LNOT_SUFFIX:
+
         switch (Op->Common.AmlOpcode)
         {
         case AML_LEQUAL_OP:
+
             AcpiOsPrintf ("LNotEqual");
             break;
 
         case AML_LGREATER_OP:
+
             AcpiOsPrintf ("LLessEqual");
             break;
 
         case AML_LLESS_OP:
+
             AcpiOsPrintf ("LGreaterEqual");
             break;
 
         default:
+
             break;
         }
         Op->Common.DisasmOpcode = 0;
@@ -662,7 +673,6 @@ AcpiDmDisassembleOneOp (
         AcpiOsPrintf ("0x%2.2X", (UINT32) Op->Common.Value.Integer);
         break;
 
-
     case AML_WORD_OP:
 
         if (Op->Common.DisasmOpcode == ACPI_DASM_EISAID)
@@ -675,7 +685,6 @@ AcpiDmDisassembleOneOp (
         }
         break;
 
-
     case AML_DWORD_OP:
 
         if (Op->Common.DisasmOpcode == ACPI_DASM_EISAID)
@@ -688,24 +697,20 @@ AcpiDmDisassembleOneOp (
         }
         break;
 
-
     case AML_QWORD_OP:
 
         AcpiOsPrintf ("0x%8.8X%8.8X",
             ACPI_FORMAT_UINT64 (Op->Common.Value.Integer));
         break;
 
-
     case AML_STRING_OP:
 
-        AcpiUtPrintString (Op->Common.Value.String, ACPI_UINT8_MAX);
+        AcpiUtPrintString (Op->Common.Value.String, ACPI_UINT16_MAX);
         break;
 
-
     case AML_BUFFER_OP:
-
         /*
-         * Determine the type of buffer.  We can have one of the following:
+         * Determine the type of buffer. We can have one of the following:
          *
          * 1) ResourceTemplate containing Resource Descriptors.
          * 2) Unicode String buffer
@@ -718,7 +723,7 @@ AcpiDmDisassembleOneOp (
          */
         if (!AcpiGbl_NoResourceDisassembly)
         {
-            Status = AcpiDmIsResourceTemplate (Op);
+            Status = AcpiDmIsResourceTemplate (WalkState, Op);
             if (ACPI_SUCCESS (Status))
             {
                 Op->Common.DisasmOpcode = ACPI_DASM_RESOURCE;
@@ -741,6 +746,11 @@ AcpiDmDisassembleOneOp (
             Op->Common.DisasmOpcode = ACPI_DASM_STRING;
             AcpiOsPrintf ("Buffer");
         }
+        else if (AcpiDmIsPldBuffer (Op))
+        {
+            Op->Common.DisasmOpcode = ACPI_DASM_PLD_METHOD;
+            AcpiOsPrintf ("Buffer");
+        }
         else
         {
             Op->Common.DisasmOpcode = ACPI_DASM_BUFFER;
@@ -748,7 +758,6 @@ AcpiDmDisassembleOneOp (
         }
         break;
 
-
     case AML_INT_STATICSTRING_OP:
 
         if (Op->Common.Value.String)
@@ -761,13 +770,11 @@ AcpiDmDisassembleOneOp (
         }
         break;
 
-
     case AML_INT_NAMEPATH_OP:
 
         AcpiDmNamestring (Op->Common.Value.Name);
         break;
 
-
     case AML_INT_NAMEDFIELD_OP:
 
         Length = AcpiDmDumpName (Op->Named.Name);
@@ -778,7 +785,6 @@ AcpiDmDisassembleOneOp (
         Info->BitOffset += (UINT32) Op->Common.Value.Integer;
         break;
 
-
     case AML_INT_RESERVEDFIELD_OP:
 
         /* Offset() -- Must account for previous offsets */
@@ -798,7 +804,6 @@ AcpiDmDisassembleOneOp (
         AcpiDmCommaIfFieldMember (Op);
         break;
 
-
     case AML_INT_ACCESSFIELD_OP:
     case AML_INT_EXTACCESSFIELD_OP:
 
@@ -816,9 +821,7 @@ AcpiDmDisassembleOneOp (
         AcpiDmCommaIfFieldMember (Op);
         break;
 
-
     case AML_INT_CONNECTION_OP:
-
         /*
          * Two types of Connection() - one with a buffer object, the
          * other with a namestring that points to a buffer object.
@@ -858,7 +861,6 @@ AcpiDmDisassembleOneOp (
         AcpiDmByteList (Info, Op);
         break;
 
-
     case AML_INT_METHODCALL_OP:
 
         Op = AcpiPsGetDepthNext (NULL, Op);
@@ -867,7 +869,6 @@ AcpiDmDisassembleOneOp (
         AcpiDmNamestring (Op->Common.Value.Name);
         break;
 
-
     default:
 
         /* Just get the opcode name and print it */
