@@ -8,13 +8,13 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2012, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2013, Intel Corp.
  * All rights reserved.
  *
  * 2. License
  *
  * 2.1. This is your license from Intel Corp. under its intellectual property
- * rights.  You may have additional license terms from the party that provided
+ * rights. You may have additional license terms from the party that provided
  * you this software, covering your right to use that party's intellectual
  * property rights.
  *
@@ -31,7 +31,7 @@
  * offer to sell, and import the Covered Code and derivative works thereof
  * solely to the minimum extent necessary to exercise the above copyright
  * license, and in no event shall the patent license extend to any additions
- * to or modifications of the Original Intel Code.  No other license or right
+ * to or modifications of the Original Intel Code. No other license or right
  * is granted directly or by implication, estoppel or otherwise;
  *
  * The above copyright and patent license is granted only if the following
@@ -43,11 +43,11 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification with rights to further distribute source must include
  * the above Copyright Notice, the above License, this list of Conditions,
- * and the following Disclaimer and Export Compliance provision.  In addition,
+ * and the following Disclaimer and Export Compliance provision. In addition,
  * Licensee must cause all Covered Code to which Licensee contributes to
  * contain a file documenting the changes Licensee made to create that Covered
- * Code and the date of any change.  Licensee must include in that file the
- * documentation of any changes made by any predecessor Licensee.  Licensee
+ * Code and the date of any change. Licensee must include in that file the
+ * documentation of any changes made by any predecessor Licensee. Licensee
  * must include a prominent statement that the modification is derived,
  * directly or indirectly, from Original Intel Code.
  *
@@ -55,7 +55,7 @@
  * Redistribution of source code of any substantial portion of the Covered
  * Code or modification without rights to further distribute source must
  * include the following Disclaimer and Export Compliance provision in the
- * documentation and/or other materials provided with distribution.  In
+ * documentation and/or other materials provided with distribution. In
  * addition, Licensee may not authorize further sublicense of source of any
  * portion of the Covered Code, and must include terms to the effect that the
  * license from Licensee to its licensee is limited to the intellectual
@@ -80,10 +80,10 @@
  * 4. Disclaimer and Export Compliance
  *
  * 4.1. INTEL MAKES NO WARRANTY OF ANY KIND REGARDING ANY SOFTWARE PROVIDED
- * HERE.  ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
- * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT,  ASSISTANCE,
- * INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL WILL NOT PROVIDE ANY
- * UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY DISCLAIMS ANY
+ * HERE. ANY SOFTWARE ORIGINATING FROM INTEL OR DERIVED FROM INTEL SOFTWARE
+ * IS PROVIDED "AS IS," AND INTEL WILL NOT PROVIDE ANY SUPPORT, ASSISTANCE,
+ * INSTALLATION, TRAINING OR OTHER SERVICES. INTEL WILL NOT PROVIDE ANY
+ * UPDATES, ENHANCEMENTS OR EXTENSIONS. INTEL SPECIFICALLY DISCLAIMS ANY
  * IMPLIED WARRANTIES OF MERCHANTABILITY, NONINFRINGEMENT AND FITNESS FOR A
  * PARTICULAR PURPOSE.
  *
@@ -92,14 +92,14 @@
  * COSTS OF PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES, OR FOR ANY INDIRECT,
  * SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THIS AGREEMENT, UNDER ANY
  * CAUSE OF ACTION OR THEORY OF LIABILITY, AND IRRESPECTIVE OF WHETHER INTEL
- * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES.  THESE LIMITATIONS
+ * HAS ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES. THESE LIMITATIONS
  * SHALL APPLY NOTWITHSTANDING THE FAILURE OF THE ESSENTIAL PURPOSE OF ANY
  * LIMITED REMEDY.
  *
  * 4.3. Licensee shall not export, either directly or indirectly, any of this
  * software or system incorporating such software without first obtaining any
  * required license or other approval from the U. S. Department of Commerce or
- * any other agency or department of the United States Government.  In the
+ * any other agency or department of the United States Government. In the
  * event Licensee exports any such software from the United States or
  * re-exports any such software from a foreign destination, Licensee shall
  * ensure that the distribution and export/re-export of the software is in
@@ -209,64 +209,56 @@ AcpiRsConvertAmlToResource (
             Resource->Length = INIT_RESOURCE_LENGTH (Info);
             break;
 
-
         case ACPI_RSC_INITSET:
             break;
 
-
         case ACPI_RSC_FLAGINIT:
 
             FlagsMode = TRUE;
             break;
 
-
         case ACPI_RSC_1BITFLAG:
             /*
              * Mask and shift the flag bit
              */
-            ACPI_SET8 (Destination) = (UINT8)
-                ((ACPI_GET8 (Source) >> Info->Value) & 0x01);
+            ACPI_SET8 (Destination,
+                ((ACPI_GET8 (Source) >> Info->Value) & 0x01));
             break;
 
-
         case ACPI_RSC_2BITFLAG:
             /*
              * Mask and shift the flag bits
              */
-            ACPI_SET8 (Destination) = (UINT8)
-                ((ACPI_GET8 (Source) >> Info->Value) & 0x03);
+            ACPI_SET8 (Destination,
+                ((ACPI_GET8 (Source) >> Info->Value) & 0x03));
             break;
 
-
         case ACPI_RSC_3BITFLAG:
             /*
              * Mask and shift the flag bits
              */
-            ACPI_SET8 (Destination) = (UINT8)
-                ((ACPI_GET8 (Source) >> Info->Value) & 0x07);
+            ACPI_SET8 (Destination,
+                ((ACPI_GET8 (Source) >> Info->Value) & 0x07));
             break;
 
-
         case ACPI_RSC_COUNT:
 
             ItemCount = ACPI_GET8 (Source);
-            ACPI_SET8 (Destination) = (UINT8) ItemCount;
+            ACPI_SET8 (Destination, ItemCount);
 
             Resource->Length = Resource->Length +
                 (Info->Value * (ItemCount - 1));
             break;
 
-
         case ACPI_RSC_COUNT16:
 
             ItemCount = AmlResourceLength;
-            ACPI_SET16 (Destination) = ItemCount;
+            ACPI_SET16 (Destination, ItemCount);
 
             Resource->Length = Resource->Length +
                 (Info->Value * (ItemCount - 1));
             break;
 
-
         case ACPI_RSC_COUNT_GPIO_PIN:
 
             Target = ACPI_ADD_PTR (void, Aml, Info->Value);
@@ -274,22 +266,19 @@ AcpiRsConvertAmlToResource (
 
             Resource->Length = Resource->Length + ItemCount;
             ItemCount = ItemCount / 2;
-            ACPI_SET16 (Destination) = ItemCount;
+            ACPI_SET16 (Destination, ItemCount);
             break;
 
-
         case ACPI_RSC_COUNT_GPIO_VEN:
 
             ItemCount = ACPI_GET8 (Source);
-            ACPI_SET8 (Destination) = (UINT8) ItemCount;
+            ACPI_SET8 (Destination, ItemCount);
 
             Resource->Length = Resource->Length +
                 (Info->Value * ItemCount);
             break;
 
-
         case ACPI_RSC_COUNT_GPIO_RES:
-
             /*
              * Vendor data is optional (length/offset may both be zero)
              * Examine vendor data length field first
@@ -312,19 +301,17 @@ AcpiRsConvertAmlToResource (
             }
 
             Resource->Length = Resource->Length + ItemCount;
-            ACPI_SET16 (Destination) = ItemCount;
+            ACPI_SET16 (Destination, ItemCount);
             break;
 
-
         case ACPI_RSC_COUNT_SERIAL_VEN:
 
             ItemCount = ACPI_GET16 (Source) - Info->Value;
 
             Resource->Length = Resource->Length + ItemCount;
-            ACPI_SET16 (Destination) = ItemCount;
+            ACPI_SET16 (Destination, ItemCount);
             break;
 
-
         case ACPI_RSC_COUNT_SERIAL_RES:
 
             ItemCount = (AmlResourceLength +
@@ -332,16 +319,14 @@ AcpiRsConvertAmlToResource (
                 ACPI_GET16 (Source) - Info->Value;
 
             Resource->Length = Resource->Length + ItemCount;
-            ACPI_SET16 (Destination) = ItemCount;
+            ACPI_SET16 (Destination, ItemCount);
             break;
 
-
         case ACPI_RSC_LENGTH:
 
             Resource->Length = Resource->Length + Info->Value;
             break;
 
-
         case ACPI_RSC_MOVE8:
         case ACPI_RSC_MOVE16:
         case ACPI_RSC_MOVE32:
@@ -357,7 +342,6 @@ AcpiRsConvertAmlToResource (
             AcpiRsMoveData (Destination, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_GPIO_PIN:
 
             /* Generate and set the PIN data pointer */
@@ -372,7 +356,6 @@ AcpiRsConvertAmlToResource (
             AcpiRsMoveData (Target, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_GPIO_RES:
 
             /* Generate and set the ResourceSource string pointer */
@@ -387,7 +370,6 @@ AcpiRsConvertAmlToResource (
             AcpiRsMoveData (Target, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_SERIAL_VEN:
 
             /* Generate and set the Vendor Data pointer */
@@ -402,7 +384,6 @@ AcpiRsConvertAmlToResource (
             AcpiRsMoveData (Target, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_SERIAL_RES:
 
             /* Generate and set the ResourceSource string pointer */
@@ -417,20 +398,17 @@ AcpiRsConvertAmlToResource (
             AcpiRsMoveData (Target, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_SET8:
 
             ACPI_MEMSET (Destination, Info->AmlOffset, Info->Value);
             break;
 
-
         case ACPI_RSC_DATA8:
 
             Target = ACPI_ADD_PTR (char, Resource, Info->Value);
             ACPI_MEMCPY (Destination, Source,  ACPI_GET16 (Target));
             break;
 
-
         case ACPI_RSC_ADDRESS:
             /*
              * Common handler for address descriptor flags
@@ -441,7 +419,6 @@ AcpiRsConvertAmlToResource (
             }
             break;
 
-
         case ACPI_RSC_SOURCE:
             /*
              * Optional ResourceSource (Index and String)
@@ -451,7 +428,6 @@ AcpiRsConvertAmlToResource (
                     Destination, Aml, NULL);
             break;
 
-
         case ACPI_RSC_SOURCEX:
             /*
              * Optional ResourceSource (Index and String). This is the more
@@ -466,7 +442,6 @@ AcpiRsConvertAmlToResource (
                     Destination, Aml, Target);
             break;
 
-
         case ACPI_RSC_BITMASK:
             /*
              * 8-bit encoded bitmask (DMA macro)
@@ -478,10 +453,9 @@ AcpiRsConvertAmlToResource (
             }
 
             Target = ACPI_ADD_PTR (char, Resource, Info->Value);
-            ACPI_SET8 (Target) = (UINT8) ItemCount;
+            ACPI_SET8 (Target, ItemCount);
             break;
 
-
         case ACPI_RSC_BITMASK16:
             /*
              * 16-bit encoded bitmask (IRQ macro)
@@ -495,10 +469,9 @@ AcpiRsConvertAmlToResource (
             }
 
             Target = ACPI_ADD_PTR (char, Resource, Info->Value);
-            ACPI_SET8 (Target) = (UINT8) ItemCount;
+            ACPI_SET8 (Target, ItemCount);
             break;
 
-
         case ACPI_RSC_EXIT_NE:
             /*
              * Control - Exit conversion if not equal
@@ -506,6 +479,7 @@ AcpiRsConvertAmlToResource (
             switch (Info->ResourceOffset)
             {
             case ACPI_RSC_COMPARE_AML_LENGTH:
+
                 if (AmlResourceLength != Info->Value)
                 {
                     goto Exit;
@@ -513,6 +487,7 @@ AcpiRsConvertAmlToResource (
                 break;
 
             case ACPI_RSC_COMPARE_VALUE:
+
                 if (ACPI_GET8 (Source) != Info->Value)
                 {
                     goto Exit;
@@ -526,7 +501,6 @@ AcpiRsConvertAmlToResource (
             }
             break;
 
-
         default:
 
             ACPI_ERROR ((AE_INFO, "Invalid conversion opcode"));
@@ -610,55 +584,48 @@ AcpiRsConvertResourceToAml (
             AcpiRsSetResourceHeader (INIT_RESOURCE_TYPE (Info), AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_INITGET:
             break;
 
-
         case ACPI_RSC_FLAGINIT:
             /*
              * Clear the flag byte
              */
-            ACPI_SET8 (Destination) = 0;
+            ACPI_SET8 (Destination, 0);
             break;
 
-
         case ACPI_RSC_1BITFLAG:
             /*
              * Mask and shift the flag bit
              */
-            ACPI_SET8 (Destination) |= (UINT8)
-                ((ACPI_GET8 (Source) & 0x01) << Info->Value);
+            ACPI_SET_BIT (*ACPI_CAST8 (Destination), (UINT8)
+                ((ACPI_GET8 (Source) & 0x01) << Info->Value));
             break;
 
-
         case ACPI_RSC_2BITFLAG:
             /*
              * Mask and shift the flag bits
              */
-            ACPI_SET8 (Destination) |= (UINT8)
-                ((ACPI_GET8 (Source) & 0x03) << Info->Value);
+            ACPI_SET_BIT (*ACPI_CAST8 (Destination), (UINT8)
+                ((ACPI_GET8 (Source) & 0x03) << Info->Value));
             break;
 
-
         case ACPI_RSC_3BITFLAG:
             /*
              * Mask and shift the flag bits
              */
-            ACPI_SET8 (Destination) |= (UINT8)
-                ((ACPI_GET8 (Source) & 0x07) << Info->Value);
+            ACPI_SET_BIT (*ACPI_CAST8 (Destination), (UINT8)
+                ((ACPI_GET8 (Source) & 0x07) << Info->Value));
             break;
 
-
         case ACPI_RSC_COUNT:
 
             ItemCount = ACPI_GET8 (Source);
-            ACPI_SET8 (Destination) = (UINT8) ItemCount;
+            ACPI_SET8 (Destination, ItemCount);
 
             AmlLength = (UINT16) (AmlLength + (Info->Value * (ItemCount - 1)));
             break;
 
-
         case ACPI_RSC_COUNT16:
 
             ItemCount = ACPI_GET16 (Source);
@@ -666,35 +633,32 @@ AcpiRsConvertResourceToAml (
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_COUNT_GPIO_PIN:
 
             ItemCount = ACPI_GET16 (Source);
-            ACPI_SET16 (Destination) = (UINT16) AmlLength;
+            ACPI_SET16 (Destination, AmlLength);
 
             AmlLength = (UINT16) (AmlLength + ItemCount * 2);
             Target = ACPI_ADD_PTR (void, Aml, Info->Value);
-            ACPI_SET16 (Target) = (UINT16) AmlLength;
+            ACPI_SET16 (Target, AmlLength);
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_COUNT_GPIO_VEN:
 
             ItemCount = ACPI_GET16 (Source);
-            ACPI_SET16 (Destination) = (UINT16) ItemCount;
+            ACPI_SET16 (Destination, ItemCount);
 
             AmlLength = (UINT16) (AmlLength + (Info->Value * ItemCount));
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_COUNT_GPIO_RES:
 
             /* Set resource source string length */
 
             ItemCount = ACPI_GET16 (Source);
-            ACPI_SET16 (Destination) = (UINT16) AmlLength;
+            ACPI_SET16 (Destination, AmlLength);
 
             /* Compute offset for the Vendor Data */
 
@@ -705,22 +669,20 @@ AcpiRsConvertResourceToAml (
 
             if (Resource->Data.Gpio.VendorLength)
             {
-                ACPI_SET16 (Target) = (UINT16) AmlLength;
+                ACPI_SET16 (Target, AmlLength);
             }
 
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_COUNT_SERIAL_VEN:
 
             ItemCount = ACPI_GET16 (Source);
-            ACPI_SET16 (Destination) = ItemCount + Info->Value;
+            ACPI_SET16 (Destination, ItemCount + Info->Value);
             AmlLength = (UINT16) (AmlLength + ItemCount);
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_COUNT_SERIAL_RES:
 
             ItemCount = ACPI_GET16 (Source);
@@ -728,13 +690,11 @@ AcpiRsConvertResourceToAml (
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_LENGTH:
 
             AcpiRsSetResourceLength (Info->Value, Aml);
             break;
 
-
         case ACPI_RSC_MOVE8:
         case ACPI_RSC_MOVE16:
         case ACPI_RSC_MOVE32:
@@ -747,7 +707,6 @@ AcpiRsConvertResourceToAml (
             AcpiRsMoveData (Destination, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_GPIO_PIN:
 
             Destination = (char *) ACPI_ADD_PTR (void, Aml,
@@ -756,7 +715,6 @@ AcpiRsConvertResourceToAml (
             AcpiRsMoveData (Destination, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_GPIO_RES:
 
             /* Used for both ResourceSource string and VendorData */
@@ -767,7 +725,6 @@ AcpiRsConvertResourceToAml (
             AcpiRsMoveData (Destination, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_SERIAL_VEN:
 
             Destination = (char *) ACPI_ADD_PTR (void, Aml,
@@ -776,7 +733,6 @@ AcpiRsConvertResourceToAml (
             AcpiRsMoveData (Destination, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_MOVE_SERIAL_RES:
 
             Destination = (char *) ACPI_ADD_PTR (void, Aml,
@@ -785,7 +741,6 @@ AcpiRsConvertResourceToAml (
             AcpiRsMoveData (Destination, Source, ItemCount, Info->Opcode);
             break;
 
-
         case ACPI_RSC_ADDRESS:
 
             /* Set the Resource Type, General Flags, and Type-Specific Flags */
@@ -793,7 +748,6 @@ AcpiRsConvertResourceToAml (
             AcpiRsSetAddressCommon (Aml, Resource);
             break;
 
-
         case ACPI_RSC_SOURCEX:
             /*
              * Optional ResourceSource (Index and String)
@@ -803,7 +757,6 @@ AcpiRsConvertResourceToAml (
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_SOURCE:
             /*
              * Optional ResourceSource (Index and String). This is the more
@@ -813,17 +766,15 @@ AcpiRsConvertResourceToAml (
             AcpiRsSetResourceLength (AmlLength, Aml);
             break;
 
-
         case ACPI_RSC_BITMASK:
             /*
              * 8-bit encoded bitmask (DMA macro)
              */
-            ACPI_SET8 (Destination) = (UINT8)
+            ACPI_SET8 (Destination,
                 AcpiRsEncodeBitmask (Source,
-                    *ACPI_ADD_PTR (UINT8, Resource, Info->Value));
+                    *ACPI_ADD_PTR (UINT8, Resource, Info->Value)));
             break;
 
-
         case ACPI_RSC_BITMASK16:
             /*
              * 16-bit encoded bitmask (IRQ macro)
@@ -833,7 +784,6 @@ AcpiRsConvertResourceToAml (
             ACPI_MOVE_16_TO_16 (Destination, &Temp16);
             break;
 
-
         case ACPI_RSC_EXIT_LE:
             /*
              * Control - Exit conversion if less than or equal
@@ -844,7 +794,6 @@ AcpiRsConvertResourceToAml (
             }
             break;
 
-
         case ACPI_RSC_EXIT_NE:
             /*
              * Control - Exit conversion if not equal
@@ -867,7 +816,6 @@ AcpiRsConvertResourceToAml (
             }
             break;
 
-
         case ACPI_RSC_EXIT_EQ:
             /*
              * Control - Exit conversion if equal
@@ -879,7 +827,6 @@ AcpiRsConvertResourceToAml (
             }
             break;
 
-
         default:
 
             ACPI_ERROR ((AE_INFO, "Invalid conversion opcode"));
@@ -937,5 +884,3 @@ Exit:
         return_ACPI_STATUS (AE_BAD_DATA);
     }
 #endif
-
-
