@@ -44,7 +44,7 @@ static int hda_audio_read_pins(const char *path, const char *file, fwts_list *se
 	while (fscanf(fp, "0x%hx 0x%x\n", &pin, &setting) == 2) {
 		pin_setting = calloc(1, sizeof(hda_audio_pin_setting));
 		if (pin_setting == NULL) {
-			fwts_list_free(settings, free);
+			fwts_list_free_items(settings, free);
 			fclose(fp);
 			return FWTS_ERROR;
 		}
@@ -150,6 +150,7 @@ static int hda_audio_test1(fwts_framework *fw)
 {
 	DIR *dir;
 	struct dirent *directory;
+	bool checked = false;
 
 	if ((dir = opendir("/sys/class/sound/")) == NULL)
 		return FWTS_ERROR;
@@ -157,6 +158,8 @@ static int hda_audio_test1(fwts_framework *fw)
 	while ((directory = readdir(dir)) != NULL)
 		if (strncmp(directory->d_name, "hw", 2) == 0) {
 			char path[PATH_MAX];
+
+			checked = true;
 			snprintf(path, sizeof(path), "/sys/class/sound/%s",
 				directory->d_name);
 			fwts_log_info(fw, "Checking '%s':", directory->d_name);
@@ -166,6 +169,9 @@ static int hda_audio_test1(fwts_framework *fw)
 
 	closedir(dir);
 
+	if (!checked)
+		fwts_skipped(fw, "Cannot find any BIOS set audio pin configurations.");
+
 	return FWTS_OK;
 }
 
