@@ -73,7 +73,7 @@ static char *cache_to_string(int type)
 	if (type & WRITE_PROTECT)
 		strcat(str," Write-Protect");
 	if (type & DEFAULT)
-		strcat(str," Default");
+		strcat(str," Default (Most probably Uncached)");
 	if (type & UNKNOWN)
 		strcat(str," Unknown");
 	return str;
@@ -88,8 +88,10 @@ static int get_mtrrs(void)
 	if ((mtrr_list = fwts_list_new()) == NULL)
 		return FWTS_ERROR;
 
-	if ((fp = fopen("/proc/mtrr", "r")) == NULL)
+	if ((fp = fopen("/proc/mtrr", "r")) == NULL) {
+		fwts_list_free(mtrr_list, free);
 		return FWTS_ERROR;
+	}
 
 	while (!feof(fp)) {
 		char *ptr1, *ptr2;
@@ -491,7 +493,7 @@ static int mtrr_test3(fwts_framework *fw)
  					"\"BIOS and Kernel Developer's Guide for the AMD Athlon 64 and AMD "
  					"Opteron Processors\" (26094 Rev. 3.30 February 2006), section "
  					"\"13.2.1.2 SYSCFG Register\": \"The MtrrFixDramModEn bit should be set "
- 					"to 1 during BIOS initalization of the fixed MTRRs, then cleared to "
+ 					"to 1 during BIOS initialization of the fixed MTRRs, then cleared to "
  					"0 for operation.\"");
 				fwts_tag_failed(fw, FWTS_TAG_BIOS);
 			}
