@@ -119,7 +119,7 @@ static int cmosdump_test1(fwts_framework *fw)
 	unsigned char data[0x80];
 
 	/* Read CMOS Data */
-	for (i=0;i<(int)sizeof(data); i++) {
+	for (i = 0;i < (int)sizeof(data); i++) {
 		if (fwts_cmos_read(i, &data[i]) != FWTS_OK) {
 			fwts_log_error(fw, "Cannot get read/write permission on I/O ports.");
 			return FWTS_ERROR;
@@ -127,7 +127,7 @@ static int cmosdump_test1(fwts_framework *fw)
 	}
 
 	fwts_log_info_verbatum(fw, "CMOS Memory Dump:");
-	for (i=0;i<(int)sizeof(data); i+= 16) {
+	for (i = 0; i < (int)sizeof(data); i += 16) {
 		char buffer[128];
 		fwts_dump_raw_data(buffer, sizeof(buffer), data + i, i, 16);
 		fwts_log_info_verbatum(fw, "%s", buffer);
@@ -292,59 +292,6 @@ static int cmosdump_test1(fwts_framework *fw)
 		data[26]);
 	fwts_log_nl(fw);
 
-	/*
-	fwts_log_info_verbatum(fw, "Drive C: (CMOS 0x");
-	fwts_log_info_verbatum(fw, "  Number of Cylinders:    0x%2.2x%2.2x",
-		data[28], data[27]);
-	fwts_log_info_verbatum(fw, "  Number of Heads:        0x%2.2x",
-		data[29]);
-	fwts_log_info_verbatum(fw, "  Number of Sectors:      0x%2.2x",
-		data[35]);
-	fwts_log_info_verbatum(fw, "  Write precomp cylinder: 0x%2.2x%2.2x",
-		data[31], data[30]);
-	fwts_log_info_verbatum(fw, "  Control Byte:           0x%2.2x",
-		data[32]);
-	fwts_log_info_verbatum(fw, "  Landing Zone            0x%2.2x%2.2x",
-		data[34], data[33]);
-	fwts_log_nl(fw);
-
-	fwts_log_info_verbatum(fw, "Drive D:");
-	fwts_log_info_verbatum(fw, "  Number of Cylinders:    0x%2.2x%2.2x",
-		data[37], data[36]);
-	fwts_log_info_verbatum(fw, "  Number of Heads:        0x%2.2x",
-		data[38]);
-	fwts_log_info_verbatum(fw, "  Number of Sectors:      0x%2.2x",
-		data[39]);
-	fwts_log_info_verbatum(fw, "  Write precomp cylinder: 0x%2.2x%2.2x",
-		data[41], data[40]);
-	fwts_log_info_verbatum(fw, "  Control Byte:           0x%2.2x",
-		data[41]);
-	fwts_log_info_verbatum(fw, "  Landing Zone            0x%2.2x%2.2x",
-		data[44], data[43]);
-	fwts_log_nl(fw);
-	*/
-
-	/* AMI only
-	fwts_log_info_verbatum(fw, "System Operational Flags:");
-	fwts_log_info_verbatum("  Turbo switch:           0x%1.1x (%s)",
-		(data[45] >> 0) & 1, (data[45] >> 0) & 1 ? "Yes" : "No");
-	fwts_log_info_verbatum(fw, "  Fast gate A20 operation 0x%1.1x (%s)",
-		(data[45] >> 1) & 1, (data[45] >> 1) & 1 ? "Yes" : "No");
-	fwts_log_info_verbatum(fw, "  Internal Cache:         0x%1.1x (%s)",
-		(data[45] >> 2) & 1, (data[45] >> 2) & 1 ? "Yes" : "No");
-	fwts_log_info_verbatum(fw, "  External Cache:         0x%1.1x (%s)",
-		(data[45] >> 3) & 1, (data[45] >> 3) & 1 ? "Yes" : "No");
-	fwts_log_info_verbatum(fw, "  Boot CPU speed:         0x%1.1x (%s)",
-		(data[45] >> 4) & 1, (data[45] >> 4) & 1 ? "Yes" : "No");
-	fwts_log_info_verbatum(fw, "  Boot Sequence:          0x%1.1x (%s)",
-		(data[45] >> 5) & 1, (data[45] >> 5) & 1 ? "Yes" : "No");
-	fwts_log_info_verbatum(fw, "  Floppy boot seek:       0x%1.1x (%s)",
-		(data[45] >> 6) & 1, (data[45] >> 6) & 1 ? "Yes" : "No");
-	fwts_log_info_verbatum(fw, "  Weitek CPU:             0x%1.1x (%s)",
-		(data[45] >> 7) & 1, (data[45] >> 7) & 1 ? "Yes" : "No");
-	fwts_log_nl(fw);
-	*/
-
 	fwts_log_info_verbatum(fw, "CMOS Checksum:(CMOS 0x2e):0x%2.2x%2.2x",
 		data[47], data[46]);
 	fwts_log_nl(fw);
@@ -362,88 +309,11 @@ static int cmosdump_test1(fwts_framework *fw)
 		(data[51] >> 7) & 1, (data[51] >> 7) & 1 ? "128KB" : "64KB");
 	fwts_log_nl(fw);
 
-	/*
-	fwts_log_info_verbatum(fw, "BIOS and Shadow Option flags:");
-	fwts_log_info_verbatum(fw, "  Password checking:      0x%1.1x %s",
-		(data[52] >> 6) & 1,
-		(data[52] >> 6) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  Boot sector virus prot: 0x%1.1x %s",
-		(data[52] >> 7) & 1,
-		(data[52] >> 7) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  Numeric CPU test:       0x%1.1x %s",
-		(data[53] >> 0) & 1,
-		(data[53] >> 0) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xC000:      0x%1.1x %s",
-		(data[53] >> 2) & 1,
-		(data[53] >> 2) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xC400:      0x%1.1x %s",
-		(data[53] >> 1) & 1,
-		(data[53] >> 1) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xC800:      0x%1.1x %s",
-		(data[52] >> 5) & 1,
-		(data[52] >> 5) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xCC00:      0x%1.1x %s",
-		(data[52] >> 4) & 1,
-		(data[52] >> 4) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xD000:      0x%1.1x %s",
-		(data[52] >> 3) & 1,
-		(data[52] >> 3) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xD400:      0x%1.1x %s",
-		(data[52] >> 2) & 1,
-		(data[52] >> 2) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xD800:      0x%1.1x %s",
-		(data[52] >> 1) & 1,
-		(data[52] >> 1) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xDC00:      0x%1.1x %s",
-		(data[52] >> 0) & 1,
-		(data[52] >> 0) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xE000:      0x%1.1x %s",
-		(data[53] >> 7) & 1,
-		(data[53] >> 7) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xE400:      0x%1.1x %s",
-		(data[53] >> 6) & 1,
-		(data[53] >> 6) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xE800:      0x%1.1x %s",
-		(data[53] >> 5) & 1,
-		(data[53] >> 5) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xEC00:      0x%1.1x %s",
-		(data[53] >> 4) & 1,
-		(data[53] >> 4) & 1 ? "Enabled" : "Disabled");
-	fwts_log_info_verbatum(fw, "  ROM shadow 0xF000:      0x%1.1x %s",
-		(data[53] >> 3) & 1,
-		(data[53] >> 3) & 1 ? "Enabled" : "Disabled");
-	fwts_log_nl(fw);
-	*/
-
-	/* AMI
-	fwts_log_info_verbatum(fw, "Encrypted Password:       0x%2.2x%2.2x%2.2x%2.2x%2.2x%2.2x",
-		data[56], data[57], data[58], data[59], data[60], data[61]);
-	fwts_log_info_verbatum(fw, "Extended CMOS checksum:   0x%2.2x%2.2x",
-		data[62], data[63]);
-
-	fwts_log_info_verbatum(fw, "Model Number:             0x%2.2x",
-		data[64]);
-	fwts_log_info_verbatum(fw, "Serial Number:            0x%2.2x%2.2x%2.2x%2.2x%2.2x%2.2x",
-		data[65], data[66], data[67], data[68], data[69], data[70]);
-	fwts_log_info_verbatum(fw, "CRC byte:                 0x%2.2x",
-		data[71]);
-	fwts_log_info_verbatum(fw, "Century Byte:             0x%2.2x",
-		data[72]);
-	fwts_log_info_verbatum(fw, "Date Alarm:               0x%2.2x",
-		data[73]);
-	fwts_log_info_verbatum(fw, "RTC Address:              0x%2.2x%2.2x",
-		data[79], data[78]);
-	fwts_log_info_verbatum(fw, "Extended RAM address:     0x%2.2x%2.2x",
-		data[81], data[80]);
-	fwts_log_nl(fw);
-	*/
-
 	fwts_infoonly(fw);
 
 	return FWTS_OK;
 }
 
-
 static fwts_framework_minor_test cmosdump_tests[] = {
 	{ cmosdump_test1, "Dump CMOS Memory." },
 	{ NULL, NULL }
