@@ -23,8 +23,6 @@
 
 #include "fwts.h"
 
-#ifdef FWTS_ARCH_INTEL
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -41,6 +39,8 @@
 
 #define FWTS_CPU_PATH	"/sys/devices/system/cpu"
 
+#define MAX_FREQS	256
+
 typedef struct {
 	uint32_t	Hz;
 	uint64_t	speed;
@@ -94,6 +94,7 @@ static void set_governor(fwts_framework *fw, const int cpu)
 	}
 }
 
+#ifdef FWTS_ARCH_INTEL
 static int cpu_exists(int cpu)
 {
 	char path[PATH_MAX];
@@ -101,6 +102,7 @@ static int cpu_exists(int cpu)
 	cpu_mkpath(path, sizeof(path), cpu, "scaling_governor");
 	return !access(path, R_OK);
 }
+#endif
 
 static void set_HZ(fwts_framework *fw, const int cpu, const unsigned long Hz)
 {
@@ -127,6 +129,7 @@ static void set_HZ(fwts_framework *fw, const int cpu, const unsigned long Hz)
 
 }
 
+#ifdef FWTS_ARCH_INTEL
 static int get_performance_repeat(
 	fwts_framework *fw,
 	const int cpu,
@@ -167,7 +170,10 @@ static int get_performance_repeat(
 		*retval = min;
 		break;
 	case GET_PERFORMANCE_AVG:
-		*retval = cumulative / real_count;
+		if (real_count)
+			*retval = cumulative / real_count;
+		else
+			*retval = 0;
 		break;
 	default:
 		*retval = 0;
@@ -175,6 +181,7 @@ static int get_performance_repeat(
 	}
 	return FWTS_OK;
 }
+#endif
 
 static char *HzToHuman(unsigned long hz)
 {
@@ -197,8 +204,6 @@ static char *HzToHuman(unsigned long hz)
 	}
 }
 
-
-
 static uint32_t get_claimed_hz(const int cpu)
 {
 	char path[PATH_MAX];
@@ -214,14 +219,22 @@ static uint32_t get_claimed_hz(const int cpu)
 	return value;
 }
 
+static int cpu_freq_compare(const void *v1, const void *v2)
+{
+	const fwts_cpu_freq *cpu_freq1 = (fwts_cpu_freq *)v1;
+	const fwts_cpu_freq *cpu_freq2 = (fwts_cpu_freq *)v2;
+
+	return cpu_freq1->Hz - cpu_freq2->Hz;
+}
+
 static void do_cpu(fwts_framework *fw, int cpu)
 {
 	char path[PATH_MAX];
 	char line[4096];
-	fwts_cpu_freq freqs[32];
+	fwts_cpu_freq freqs[MAX_FREQS];
 	FILE *file;
 	char *c, *c2;
-	int i, delta;
+	int i;
 	int speedcount;
 	static int warned=0;
 	int warned_PSS = 0;
@@ -240,8 +253,10 @@ static void do_cpu(fwts_framework *fw, int cpu)
 		}
 		return;
 	}
-	if (fgets(line, 4095, file) == NULL)
+	if (fgets(line, 4095, file) == NULL) {
+		fclose(file);
 		return;
+	}
 	fclose(file);
 
 	if (total_tests == 1)
@@ -250,7 +265,7 @@ static void do_cpu(fwts_framework *fw, int cpu)
 
 	c = line;
 	i = 0;
-	while (c && strlen(c) > 1) {
+	while ((i < MAX_FREQS) && c && strlen(c) > 1) {
 		c2 = strchr(c, ' ');
 		if (c2) {
 			*c2 = 0;
@@ -302,21 +317,8 @@ static void do_cpu(fwts_framework *fw, int cpu)
 	if (speedcount<2)
 		return;
 
-	/* Now.. sort the frequencies */
-
-	delta=1;
-	while (delta) {
-		fwts_cpu_freq tmp;
-		delta = 0;
-		for (i = 0; i < speedcount-1; i++) {
-			if (freqs[i].Hz > freqs[i+1].Hz) {
-				tmp = freqs[i];
-				freqs[i] = freqs[i+1];
-				freqs[i+1] = tmp;
-				delta = 1;
-			}
-		}
-	}
+	/* Sort the frequencies */
+	qsort(freqs, speedcount, sizeof(fwts_cpu_freq), cpu_freq_compare);
 
 	/* now check for 1) increasing HZ and 2) increasing speed */
 	for (i = 0; i < speedcount-1; i++) {
@@ -328,7 +330,7 @@ static void do_cpu(fwts_framework *fw, int cpu)
 			fwts_failed(fw, LOG_LEVEL_MEDIUM,
 				"CPUFreqSlowerOnCPU",
 				"Supposedly higher frequency %s is slower (%" PRIu64
-				" bogo loops) than frequency %s (%" PRIu64 
+				" bogo loops) than frequency %s (%" PRIu64
 				" bogo loops) on CPU %i.",
 				HzToHuman(freqs[i+1].Hz), freqs[i+1].speed,
 				HzToHuman(freqs[i].Hz), freqs[i].speed,
@@ -406,6 +408,7 @@ static void highest_speed(fwts_framework *fw, const int cpu)
 }
 
 
+#ifdef FWTS_ARCH_INTEL
 /*
  * 4) Is BIOS wrongly doing Sw_All P-state coordination across cpus
  * - Change frequency on all CPU to the lowest value
@@ -496,6 +499,7 @@ static void do_sw_any_test(fwts_framework *fw)
 	if (get_performance_repeat(fw, first_cpu_index, 5, GET_PERFORMANCE_MIN, &lowperf) != FWTS_OK) {
 		fwts_failed(fw, LOG_LEVEL_MEDIUM, "CPUFreqSW_ANYGetPerf",
 			"Failed to get CPU performance.");
+		closedir(dir);
 		return;
 	}
 	lowperf = (100 * lowperf) / top_speed;
@@ -527,7 +531,6 @@ static void do_sw_any_test(fwts_framework *fw)
 			"instead?.");
 }
 
-
 static void check_sw_any(fwts_framework *fw)
 {
 	DIR *dir;
@@ -604,8 +607,9 @@ static void check_sw_any(fwts_framework *fw)
 		fwts_progress(fw, 100 * performed_tests/total_tests);
 	}
 	if (!once)
-		fwts_passed(fw, "P-state coordination done by Hardware.");
+		fwts_passed(fw, "P-state coordination under hardware control.");
 }
+#endif
 
 static int cpufreq_test1(fwts_framework *fw)
 {
@@ -613,7 +617,7 @@ static int cpufreq_test1(fwts_framework *fw)
 	struct dirent *entry;
 	int cpu;
 
-	/* Do your test */
+#ifdef FWTS_ARCH_INTEL
 	fwts_log_info(fw,
 		"For each processor in the system, this test steps through the "
 		"various frequency states (P-states) that the BIOS advertises "
@@ -624,6 +628,16 @@ static int cpufreq_test1(fwts_framework *fw)
 	fwts_log_info_verbatum(fw, "  3. No duplicate frequency values are reported by the BIOS.");
 	fwts_log_info_verbatum(fw, "  4. BIOS doing Sw_All P-state coordination across cores.");
 	fwts_log_info_verbatum(fw, "  5. BIOS doing Sw_Any P-state coordination across cores.");
+#else
+	fwts_log_info(fw,
+		"For each processor in the system, this test steps through the "
+		"various frequency states that the CPU supports. "
+		"For each processor/frequency combination, "
+		"a quick performance value is measured. The test then validates that:");
+	fwts_log_info_verbatum(fw, "  1. Each processor has the same number of frequency states.");
+	fwts_log_info_verbatum(fw, "  2. Higher advertised frequencies have a higher performance.");
+	fwts_log_info_verbatum(fw, "  3. No duplicate frequency values exist.");
+#endif
 	fwts_log_nl(fw);
 
 	/* First set all processors to their lowest speed */
@@ -663,6 +677,7 @@ static int cpufreq_test1(fwts_framework *fw)
 	}
 	closedir(dir);
 
+#ifdef FWTS_ARCH_INTEL
 	if (!no_cpufreq)
 		check_sw_any(fw);
 
@@ -681,7 +696,7 @@ static int cpufreq_test1(fwts_framework *fw)
 		performed_tests += 2;
 		fwts_progress(fw, 100 * performed_tests/total_tests);
 	}
-
+#endif
 	fwts_progress(fw, 100);
 
 	return FWTS_OK;
@@ -697,16 +712,18 @@ static int cpufreq_init(fwts_framework *fw)
 }
 
 static fwts_framework_minor_test cpufreq_tests[] = {
+#ifdef FWTS_ARCH_INTEL
 	{ cpufreq_test1, "CPU P-State Checks." },
+#else
+	{ cpufreq_test1, "CPU Frequency Checks." },
+#endif
 	{ NULL, NULL }
 };
 
 static fwts_framework_ops cpufreq_ops = {
 	.init        = cpufreq_init,
-	.description = "CPU frequency scaling tests (takes ~1-2 mins).",
+	.description = "CPU frequency scaling tests.",
 	.minor_tests = cpufreq_tests
 };
 
 FWTS_REGISTER("cpufreq", &cpufreq_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
-
-#endif
