@@ -84,6 +84,7 @@ static int hotkey_test(fwts_framework *fw, char *dev, fwts_list *hotkeys)
 
 	if (ioctl(fd, EVIOCGRAB, (void*)1)) {	/* Get focus */
 		fwts_log_error(fw, "Cannot grab device %s.", path);
+		close(fd);
 		return FWTS_ERROR;
 	}
 
@@ -106,6 +107,7 @@ static int hotkey_test(fwts_framework *fw, char *dev, fwts_list *hotkeys)
 
 	if (ioctl(fd, EVIOCGRAB, (void*)0)) {	/* Release */
 		fwts_log_error(fw, "Cannot un-grab device %s.", path);
+		close(fd);
 		return FWTS_ERROR;
 	}
 	close(fd);
@@ -152,19 +154,20 @@ static char *hotkey_find_keyboard(char *path)
 		if (strlen(entry->d_name) > 3) {
 			snprintf(filename, sizeof(filename), "%s/%s",
 				path, entry->d_name);
-			lstat(filename, &statbuf);
-			if (S_ISDIR(statbuf.st_mode)) {
-				if (!S_ISLNK(statbuf.st_mode))
-					if ((dev = hotkey_find_keyboard(filename)) != NULL)
-						break;
-			} else {
-				if ((data = fwts_get(filename)) != NULL) {
-					if (strncmp(data, AT_KEYBOARD, sizeof(AT_KEYBOARD)-1) == 0) {
-						dev = hotkey_device(path);
+			if (lstat(filename, &statbuf) == 0) {
+				if (S_ISDIR(statbuf.st_mode)) {
+					if (!S_ISLNK(statbuf.st_mode))
+						if ((dev = hotkey_find_keyboard(filename)) != NULL)
+							break;
+				} else {
+					if ((data = fwts_get(filename)) != NULL) {
+						if (strncmp(data, AT_KEYBOARD, sizeof(AT_KEYBOARD)-1) == 0) {
+							dev = hotkey_device(path);
+							free(data);
+							break;
+						}
 						free(data);
-						break;
 					}
-					free(data);
 				}
 			}
 		}
@@ -228,10 +231,8 @@ static int hotkey_deinit(fwts_framework *fw)
 	FWTS_UNUSED(fw);
 
 	fwts_keymap_free(hotkeys);
-	if (hotkey_dev)
-		free(hotkey_dev);
-	if (hotkey_keymap)
-		free(hotkey_keymap);
+	free(hotkey_dev);
+	free(hotkey_keymap);
 	return FWTS_OK;
 }
 
