@@ -26,6 +26,7 @@
 
 #include "fwts_log.h"
 #include "fwts_list.h"
+#include "fwts_acpica_mode.h"
 
 #define FWTS_FRAMEWORK_MAGIC	0x2af61aec
 
@@ -36,6 +37,7 @@ typedef enum {
 	FWTS_FLAG_FORCE_CLEAN			= 0x00000004,
 	FWTS_FLAG_SHOW_TESTS			= 0x00000008,
 	FWTS_FLAG_SHOW_PROGRESS_DIALOG		= 0x00000010,
+	FWTS_FLAG_ACPICA_DEBUG			= 0x00000020,
 	FWTS_FLAG_BATCH				= 0x00001000,
 	FWTS_FLAG_INTERACTIVE			= 0x00002000,
 	FWTS_FLAG_BATCH_EXPERIMENTAL		= 0x00004000,
@@ -141,6 +143,7 @@ typedef struct {
 	fwts_list errors_filter_keep;		/* Results to keep, empty = keep all */
 	fwts_list errors_filter_discard;	/* Results to discard, empty = discard none */
 	bool error_filtered_out;		/* True if a klog message has been filtered out */
+	fwts_acpica_mode acpica_mode;		/* ACPICA mode flags */
 } fwts_framework;
 
 typedef struct {
