@@ -88,6 +88,12 @@ enum {
 
 #define FWTS_UEFI_UNSPECIFIED_TIMEZONE 0x07FF
 
+#define EFI_OS_INDICATIONS_BOOT_TO_FW_UI			0x0000000000000001
+#define EFI_OS_INDICATIONS_TIMESTAMP_REVOCATION 		0x0000000000000002
+#define EFI_OS_INDICATIONS_FILE_CAPSULE_DELIVERY_SUPPORTED	0x0000000000000004
+#define EFI_OS_INDICATIONS_FMP_CAPSULE_SUPPORTED 		0x0000000000000008
+#define EFI_OS_INDICATIONS_CAPSULE_RESULT_VAR_SUPPORTED		0x0000000000000010
+
 #if 0
 typedef struct {
 	char *description;
@@ -356,4 +362,6 @@ int fwts_uefi_get_variable_names(fwts_list *list);
 void fwts_uefi_print_status_info(fwts_framework *fw, const uint64_t status);
 char *fwts_uefi_attribute_info(uint32_t attr);
 
+bool fwts_uefi_efivars_iface_exist(void);
+
 #endif
