@@ -51,30 +51,23 @@ static pid_t *fwts_cpu_pids;
  */
 int fwts_cpu_readmsr(const int cpu, const uint32_t reg, uint64_t *val)
 {
-	struct stat statbuf;
 	char buffer[PATH_MAX];
-	uint64_t value;
+	uint64_t value = 0;
 	int fd;
 	int ret;
 
-	value = 0;
-
 	snprintf(buffer, sizeof(buffer), "/dev/cpu/%d/msr", cpu);
-
-	if (stat(buffer, &statbuf)) {
+	if ((fd = open(buffer, O_RDONLY)) < 0) {
 		/* Hrm, msr not there, so force modprobe msr and see what happens */
 		pid_t pid;
 		if ((fd = fwts_pipe_open("modprobe msr", &pid)) < 0)
 			return FWTS_ERROR;
 		fwts_pipe_close(fd, pid);
 
-		if (stat(buffer, &statbuf))
+		if ((fd = open(buffer, O_RDONLY)) < 0)
 			return FWTS_ERROR; /* Really failed */
 	}
 
-	if ((fd = open(buffer, O_RDONLY)) < 0)
-                return FWTS_ERROR;
-
 	ret = pread(fd, &value, 8, reg);
 	close(fd);
 
@@ -114,8 +107,10 @@ fwts_cpuinfo_x86 *fwts_cpu_get_info(const int which_cpu)
 	if ((cpu = (fwts_cpuinfo_x86*)calloc(1, sizeof(fwts_cpuinfo_x86))) == NULL)
 		return NULL;
 
-	if ((fp = fopen("/proc/cpuinfo", "r")) == NULL)
+	if ((fp = fopen("/proc/cpuinfo", "r")) == NULL) {
+		free(cpu);
 		return NULL;
+	}
 
 	while (fgets(buffer, sizeof(buffer), fp) != NULL) {
 		char *ptr = strstr(buffer, ":");
@@ -383,7 +378,7 @@ int fwts_cpu_performance(
 static void fwts_cpu_consume_cycles(void)
 {
 	signal(SIGUSR1, fwts_cpu_consume_sighandler);
-	uint64_t i;
+	uint64_t i = 0;
 
 	for (;;) {
 		fwts_cpu_burn_cycles();
