@@ -31,17 +31,15 @@
 /* Suffix ".log", ".xml", etc gets automatically appended */
 #define RESULTS_LOG	"results"
 
-#define FWTS_FLAG_RUN_ALL		\
+#define FWTS_FLAG_RUN_ALL			\
 	(FWTS_FLAG_BATCH |			\
 	 FWTS_FLAG_INTERACTIVE |		\
-	 FWTS_FLAG_BATCH_EXPERIMENTAL |	\
-	 FWTS_FLAG_INTERACTIVE_EXPERIMENTAL |\
+	 FWTS_FLAG_BATCH_EXPERIMENTAL |		\
+	 FWTS_FLAG_INTERACTIVE_EXPERIMENTAL |	\
 	 FWTS_FLAG_POWER_STATES |		\
 	 FWTS_FLAG_UTILS |			\
-	 FWTS_FLAG_UNSAFE)
-
-#define FWTS_ARGS_WIDTH 	28
-#define FWTS_MIN_TTY_WIDTH	50
+	 FWTS_FLAG_UNSAFE |			\
+	 FWTS_FLAG_TEST_UEFI)
 
 static fwts_list tests_to_skip;
 
@@ -79,21 +77,17 @@ static fwts_option fwts_framework_options[] = {
 	{ "lp-tags-log", 	"",   0, "Output LaunchPad bug tags in results log." },
 	{ "disassemble-aml", 	"",   0, "Disassemble AML from DSDT and SSDT tables." },
 	{ "log-type",		"",   1, "Specify log type (plaintext, json, html or xml)." },
-	{ "unsafe",		"U",  0, "Unsafe tests (tests that can potentially cause kernel oopses." },
+	{ "unsafe",		"U",  0, "Unsafe tests (tests that can potentially cause kernel oopses)." },
 	{ "filter-error-discard", "", 1, "Discard errors that match any of the specified labels." },
 	{ "filter-error-keep",	"",   1, "Keep errors that match any of the specified labels." },
+	{ "acpica-debug",	"",   0, "Enable ACPICA debug/warning messages." },
+	{ "acpica",		"",   1, "Enable ACPICA run time options." },
+	{ "uefi",		"",   0, "Run UEFI tests." },
 	{ NULL, NULL, 0, NULL }
 };
 
 static fwts_list fwts_framework_test_list = FWTS_LIST_INIT;
 
-typedef struct {
-	const int env_id;
-	const char *env_name;
-	const char *env_default;
-	char *env_value;
-} fwts_framework_setting;
-
 static const char *fwts_copyright[] = {
 	"Some of this work - Copyright (c) 1999 - 2010, Intel Corp. All rights reserved.",
 	"Some of this work - Copyright (c) 2010 - 2013, Canonical.",
@@ -119,7 +113,8 @@ static int fwts_framework_compare_priority(void *data1, void *data2)
  *    be reported to stderr because the logging engine
  *    is not set up yet.
  */
-void fwts_framework_test_add(const char *name,
+void fwts_framework_test_add(
+	const char *name,
 	fwts_framework_ops *ops,
 	const fwts_priority priority,
 	const fwts_framework_flags flags)
@@ -139,7 +134,9 @@ void fwts_framework_test_add(const char *name,
 	}
 
 	/* Total up minor tests in this test */
-	for (ops->total_tests = 0; ops->minor_tests[ops->total_tests].test_func != NULL; ops->total_tests++)
+	for (ops->total_tests = 0; 
+	     ops->minor_tests[ops->total_tests].test_func != NULL;
+	     ops->total_tests++)
 		;
 
 	new_test->name = name;
@@ -152,11 +149,8 @@ void fwts_framework_test_add(const char *name,
 
 	/* Add any options and handler, if they exists */
 	if (ops->options && ops->options_handler) {
-		int ret;
-
-		ret = fwts_args_add_options(ops->options, ops->options_handler,
-			ops->options_check);
-		if (ret == FWTS_ERROR) {
+		if (fwts_args_add_options(ops->options, ops->options_handler,
+			ops->options_check) == FWTS_ERROR) {
 			fprintf(stderr, "FATAL: Could not allocate memory "
 				"for getopt options handler.");
 			exit(EXIT_FAILURE);
@@ -184,8 +178,8 @@ static void fwts_framework_show_tests_brief(void)
 {
 	fwts_list sorted;
 	fwts_list_link *item;
-	int n = 0;
-	int width = fwts_tty_width(fileno(stderr), 80);
+	size_t n = 0;
+	size_t width = (size_t)fwts_tty_width(fileno(stderr), 80);
 
 	fwts_list_init(&sorted);
 
@@ -197,7 +191,7 @@ static void fwts_framework_show_tests_brief(void)
 
 	fwts_list_foreach(item, &sorted) {
 		fwts_framework_test *test = fwts_list_data(fwts_framework_test*, item);
-		int len = strlen(test->name) + 1;
+		size_t len = strlen(test->name) + 1;
 		if ((n + len) > width)  {
 			fprintf(stderr, "\n");
 			n = 0;
@@ -214,12 +208,12 @@ static void fwts_framework_show_tests_brief(void)
  *  fwts_framework_show_tests()
  *	dump out registered tests.
  */
-static void fwts_framework_show_tests(fwts_framework *fw, bool full)
+static void fwts_framework_show_tests(fwts_framework *fw, const bool full)
 {
 	fwts_list_link *item;
 	fwts_list sorted;
 	int i;
-	int need_nl = 0;
+	bool need_nl = false;
 	int total = 0;
 
 	typedef struct {
@@ -235,11 +229,12 @@ static void fwts_framework_show_tests(fwts_framework *fw, bool full)
 		{ "Power States",		FWTS_FLAG_POWER_STATES },
 		{ "Utilities",			FWTS_FLAG_UTILS },
 		{ "Unsafe",			FWTS_FLAG_UNSAFE },
+		{ "UEFI",			FWTS_FLAG_TEST_UEFI },
 		{ NULL,				0 },
 	};
 
 	/* Dump out tests registered under all categories */
-	for (i=0; categories[i].title != NULL; i++) {
+	for (i = 0; categories[i].title != NULL; i++) {
 		fwts_framework_test *test;
 
 		/* If no category flags are set, or category matches user requested
@@ -249,7 +244,7 @@ static void fwts_framework_show_tests(fwts_framework *fw, bool full)
 			fwts_list_init(&sorted);
 			fwts_list_foreach(item, &fwts_framework_test_list) {
 				test = fwts_list_data(fwts_framework_test *, item);
-				if ((test->flags & FWTS_FLAG_RUN_ALL) == categories[i].flag)
+				if ((test->flags & FWTS_FLAG_RUN_ALL) & categories[i].flag)
 					fwts_list_add_ordered(&sorted, test,
 						fwts_framework_compare_test_name);
 			}
@@ -257,7 +252,7 @@ static void fwts_framework_show_tests(fwts_framework *fw, bool full)
 			if (fwts_list_len(&sorted) > 0) {
 				if (need_nl)
 					printf("\n");
-				need_nl = 1;
+				need_nl = true;
 				printf("%s%s:\n", categories[i].title,
 					categories[i].flag & FWTS_FLAG_UTILS ? "" : " tests");
 
@@ -268,7 +263,7 @@ static void fwts_framework_show_tests(fwts_framework *fw, bool full)
 						printf(" %-15.15s (%d test%s):\n",
 							test->name, test->ops->total_tests,
 							test->ops->total_tests > 1 ? "s" : "");
-						for (j=0; j<test->ops->total_tests;j++)
+						for (j = 0; j < test->ops->total_tests; j++)
 							printf("  %s\n", test->ops->minor_tests[j].name);
 						total += test->ops->total_tests;
 					}
@@ -291,13 +286,15 @@ static void fwts_framework_show_tests(fwts_framework *fw, bool full)
  */
 static void fwts_framework_strtrunc(char *dest, const char *src, size_t max)
 {
-	strncpy(dest, src, max);
-
-	if ((strlen(src) > max) && (max > 3)) {
-		dest[max-1] = 0;
-		dest[max-2] = '.';
-		dest[max-3] = '.';
-	}
+	if (src) {
+		strncpy(dest, src, max);
+		if ((max > 3) && (strlen(src) > max)) {
+			dest[max-1] = 0;
+			dest[max-2] = '.';
+			dest[max-3] = '.';
+		}
+	} else
+		strncpy(dest, "", max);
 }
 
 /*
@@ -306,7 +303,7 @@ static void fwts_framework_strtrunc(char *dest, const char *src, size_t max)
  */
 static void fwts_framework_format_results(char *buffer, int buflen, fwts_results const *results, bool include_zero_results)
 {
-	int n = 0;
+	size_t n = 0;
 
 	if (buflen)
 		*buffer = 0;
@@ -786,8 +783,7 @@ static void fwts_framework_strdup(char **ptr, const char *str)
 	if (ptr == NULL)
 		return;
 
-	if (*ptr)
-		free(*ptr);
+	free(*ptr);
 	*ptr = strdup(str);
 }
 
@@ -805,7 +801,7 @@ static void fwts_framework_syntax(char * const *argv)
 
 	/* Tag on copyright info */
 	printf("\n");
-	for (i=0; fwts_copyright[i]; i++)
+	for (i = 0; fwts_copyright[i]; i++)
 		printf("%s\n", fwts_copyright[i]);
 }
 
@@ -835,7 +831,7 @@ static void fwts_framework_heading_info(
 
 	fwts_log_info(fw, "Results generated by fwts: Version %s (%s).", FWTS_VERSION, FWTS_DATE);
 	fwts_log_nl(fw);
-	for (i=0; fwts_copyright[i]; i++)
+	for (i = 0; fwts_copyright[i]; i++)
 		fwts_log_info(fw, "%s", fwts_copyright[i]);
 	fwts_log_nl(fw);
 
@@ -925,7 +921,7 @@ static int fwts_framework_filter_error_parse(const char *arg, fwts_list *list)
 	for (str = (char*)arg; (token = strtok_r(str, ",", &saveptr)) != NULL; str = NULL) {
 		if (fwts_list_append(list, token) == NULL) {
 			fprintf(stderr, "Out of memory parsing argument %s\n", arg);
-			fwts_list_free(list, NULL);
+			fwts_list_free_items(list, NULL);
 			return FWTS_ERROR;
 		}
 	}
@@ -966,6 +962,39 @@ static int fwts_framework_log_type_parse(fwts_framework *fw, const char *arg)
 	return FWTS_OK;
 }
 
+/*
+ *  fwts_framework_acpica_parse()
+ *	parse optarg of comma separated acpica mode flags
+ */
+static int fwts_framework_acpica_parse(fwts_framework *fw, const char *arg)
+{
+	char *str;
+	char *token;
+	char *saveptr = NULL;
+
+	fw->acpica_mode = 0;
+
+	for (str = (char*)arg; (token = strtok_r(str, ",", &saveptr)) != NULL; str = NULL) {
+		if (!strcmp(token, "serialized"))
+			fw->acpica_mode |= FWTS_ACPICA_MODE_SERIALIZED;
+		else if (!strcmp(token, "slack"))
+			fw->acpica_mode |= FWTS_ACPICA_MODE_SLACK;
+		else if (!strcmp(token, "ignore-errors"))
+			fw->acpica_mode |= FWTS_ACPICA_MODE_IGNORE_ERRORS;
+		else if (!strcmp(token, "disable-auto-repair"))
+			fw->acpica_mode |= FWTS_ACPICA_MODE_DISABLE_AUTO_REPAIR;
+		else {
+			fprintf(stderr, "--acpica can be serialized, slack, ignore-errors or disable-auto-repair\n");
+			return FWTS_ERROR;
+		}
+	}
+
+	if (!fw->log_type)
+		fw->log_type = LOG_TYPE_PLAINTEXT;
+
+	return FWTS_OK;
+}
+
 int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const argv[], int option_char, int long_index)
 {
 	FWTS_UNUSED(argc);
@@ -1026,7 +1055,7 @@ int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const ar
 			fwts_framework_show_version(stdout, argv[0]);
 			return FWTS_COMPLETE;
 		case 16: /* --dump */
-			fwts_dump_info(fw, NULL);
+			fwts_dump_info(fw);
 			return FWTS_COMPLETE;
 		case 17: /* --table-path */
 			fwts_framework_strdup(&fw->acpi_table_path, optarg);
@@ -1097,6 +1126,16 @@ int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const ar
 			if (fwts_framework_filter_error_parse(optarg, &fw->errors_filter_keep) != FWTS_OK)
 				return FWTS_ERROR;
 			break;
+		case 36: /* --acpica-debug */
+			fw->flags |= FWTS_FLAG_ACPICA_DEBUG;
+			break;
+		case 37: /* --acpica */
+			if (fwts_framework_acpica_parse(fw, optarg) != FWTS_OK)
+				return FWTS_ERROR;
+			break;
+		case 38: /* --uefi */
+			fw->flags |= FWTS_FLAG_TEST_UEFI;
+			break;
 		}
 		break;
 	case 'a': /* --all */
@@ -1106,7 +1145,7 @@ int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const ar
 		fw->flags |= FWTS_FLAG_BATCH;
 		break;
 	case 'd': /* --dump */
-		fwts_dump_info(fw, NULL);
+		fwts_dump_info(fw);
 		return FWTS_COMPLETE;
 	case 'D': /* --show-progress-dialog */
 		fw->flags = (fw->flags &
@@ -1195,7 +1234,7 @@ int fwts_framework_args(const int argc, char **argv)
 	ret = fwts_args_add_options(fwts_framework_options,
 		fwts_framework_options_handler, NULL);
 	if (ret == FWTS_ERROR)
-		return ret;
+		goto tidy_args;
 
 	fw->firmware_type = fwts_firmware_detect();
 
@@ -1227,7 +1266,7 @@ int fwts_framework_args(const int argc, char **argv)
 		goto tidy_close;
 	}
 
-	for (i=1; i<argc; i++)
+	for (i = 1; i < argc; i++)
 		if (!strcmp(argv[i], "-")) {
 			fwts_framework_strdup(&fw->results_logname, "stdout");
 			fw->flags = (fw->flags &
@@ -1284,7 +1323,7 @@ int fwts_framework_args(const int argc, char **argv)
 	}
 
 	/* Collect up tests to run */
-	for (i=optind; i < argc; i++) {
+	for (i = optind; i < argc; i++) {
 		fwts_framework_test *test;
 
 		if (*argv[i] == '-')
@@ -1354,7 +1393,6 @@ tidy:
 tidy_close:
 	fwts_acpi_free_tables();
 	fwts_summary_deinit();
-	fwts_args_free();
 
 	free(fw->lspci);
 	free(fw->results_logname);
@@ -1370,6 +1408,8 @@ tidy_close:
 	if ((fw->total.failed > 0) || (fw->total.warning > 0))
 		ret = FWTS_ERROR;
 
+tidy_args:
+	fwts_args_free();
 	free(fw);
 
 	return ret;
