@@ -16,8 +16,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
-#define LOG_LINE_WIDTH 100
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -31,6 +29,7 @@
 
 #include "fwts.h"
 
+#define LOG_LINE_WIDTH		(80)
 #define LOG_UNKOWN_FIELD	"???"
 
 static int log_line_width = 0;
@@ -482,8 +481,7 @@ int fwts_log_set_owner(fwts_log *log, const char *owner)
 	if (log && (log->magic == LOG_MAGIC)) {
 		char *newowner = strdup(owner);
 		if (newowner) {
-			if (log->owner)
-				free(log->owner);
+			free(log->owner);
 			log->owner = newowner;
 			return FWTS_OK;
 		}
@@ -579,8 +577,10 @@ char *fwts_log_get_filenames(const char *filename, const fwts_log_type type)
 	for (i=0; i<32; i++) {
 		fwts_log_type mask = 1 << i;
 		if (type & mask) {
-			if ((tmp = fwts_log_filename(filename, mask)) == NULL)
+			if ((tmp = fwts_log_filename(filename, mask)) == NULL) {
+				free(filenames);
 				return NULL;
+			}
 
 			if (filenames) {
 				len += strlen(tmp) + 2;
@@ -664,6 +664,7 @@ fwts_log *fwts_log_open(
 			case LOG_FILENAME_TYPE_FILE:
 				if ((newname = fwts_log_filename(filename, mask)) == NULL) {
 					fwts_log_close(newlog);
+					free(log_file);
 					return NULL;
 				}
 				log_file->fp = fopen(newname, mode);
@@ -671,6 +672,7 @@ fwts_log *fwts_log_open(
 
 				if (log_file->fp == NULL) {
 					fwts_log_close(newlog);
+					free(log_file);
 					return NULL;
 				}
 			}
@@ -721,9 +723,7 @@ int fwts_log_close(fwts_log *log)
 		/* ..and free log files */
 		fwts_list_free_items(&log->log_files, free);
 
-		if (log->owner)
-			free(log->owner);
-
+		free(log->owner);
 		free(log);
 	}
 	return FWTS_OK;
