@@ -60,8 +60,9 @@ typedef struct {
 #define UEFI_IFACE_EFIVARS		(3)	/* efivar fs */
 
 /* File system magic numbers */
-#define EFIVARS_FS_MAGIC	0x6165676C
-#define SYS_FS_MAGIC		0x62656572
+#define PSTOREFS_MAGIC          ((__SWORD_TYPE)0x6165676C)
+#define EFIVARFS_MAGIC          ((__SWORD_TYPE)0xde5e81e4)
+#define SYS_FS_MAGIC		((__SWORD_TYPE)0x62656572)
 
 /*
  *  fwts_uefi_get_interface()
@@ -106,8 +107,8 @@ static int fwts_uefi_get_interface(char **path)
 					strcpy(efivar_path, "/sys/firmware/efi/vars");
 			}
 		}
+		fclose(fp);
 	}
-	fclose(fp);
 
 	*path = NULL;
 
@@ -126,14 +127,15 @@ static int fwts_uefi_get_interface(char **path)
 	/* We've now found a valid file system we can use */
 	*path = efivar_path;
 
-	if (statbuf.f_type == EFIVARS_FS_MAGIC) {
+	if ((statbuf.f_type == EFIVARFS_MAGIC) ||
+	    (statbuf.f_type == PSTOREFS_MAGIC)) {
 		efivars_interface = UEFI_IFACE_EFIVARS;
 		return UEFI_IFACE_EFIVARS;
 	}
 
 	if (statbuf.f_type == SYS_FS_MAGIC) {
 		efivars_interface = UEFI_IFACE_SYSFS;
-		return UEFI_IFACE_EFIVARS;
+		return UEFI_IFACE_SYSFS;
 	}
 
 	return UEFI_IFACE_UNKNOWN;
@@ -268,33 +270,35 @@ static int fwts_uefi_get_variable_efivars_fs(const char *varname, fwts_uefi_var
 
 	snprintf(filename, sizeof(filename), "%s/%s", path, varname);
 
-	if (stat(filename, &statbuf) < 0)
+	if ((fd = open(filename, O_RDONLY)) < 0)
 		return FWTS_ERROR;
 
+	if (fstat(fd, &statbuf) < 0) {
+		close(fd);
+		return FWTS_ERROR;
+	}
+
 	/* Variable name, less the GUID, in 16 bit ints */
 	var->varname = calloc(1, (varname_len + 1 - 36)  * sizeof(uint16_t));
-	if (var->varname == NULL)
+	if (var->varname == NULL) {
+		close(fd);
 		return FWTS_ERROR;
+	}
 
 	/* Convert name to internal 16 bit version */
 	fwts_uefi_str_to_str16(var->varname, varname_len - 36, varname);
 
 	/* Need to read the data in one read, so allocate a buffer big enough */
 	if ((efivars_fs_var = calloc(1, statbuf.st_size)) == NULL) {
+		close(fd);
 		free(var->varname);
 		return FWTS_ERROR;
 	}
 
-	if ((fd = open(filename, O_RDONLY)) < 0) {
-		free(var->varname);
-		free(efivars_fs_var);
-		return FWTS_ERROR;
-	}
-
 	if (read(fd, efivars_fs_var, statbuf.st_size) != statbuf.st_size) {
+		close(fd);
 		free(var->varname);
 		free(efivars_fs_var);
-		close(fd);
 		return FWTS_ERROR;
 	}
 	close(fd);
@@ -397,7 +401,7 @@ int fwts_uefi_get_variable_names(fwts_list *list)
 		return FWTS_ERROR;
 
 	for (i = 0; i < n; i++) {
-		if (names[i]->d_name == NULL)
+		if (names[i]->d_name[0] == '\0')
 			continue;
 		if (!strcmp(names[i]->d_name, "."))
 			continue;
@@ -511,3 +515,15 @@ char *fwts_uefi_attribute_info(uint32_t attr)
 
 	return str;
 }
+
+/*
+ *  fwts_uefi_efivars_fs_exist()
+ *	check the efivar interface exist
+ */
+bool fwts_uefi_efivars_iface_exist(void)
+{
+	char *path;
+
+	return (fwts_uefi_get_interface(&path) == UEFI_IFACE_EFIVARS);
+
+}
