@@ -330,6 +330,11 @@ static int securebootcert_init(fwts_framework *fw)
 		return FWTS_ABORTED;
 	}
 
+	if (!fwts_uefi_efivars_iface_exist()) {
+		fwts_log_info(fw, "Cannot detect efivars interface. Aborted.");
+		return FWTS_ABORTED;
+	}
+
 	return FWTS_OK;
 }
 
@@ -383,4 +388,4 @@ static fwts_framework_ops securebootcert_ops = {
 	.minor_tests = securebootcert_tests
 };
 
-FWTS_REGISTER("securebootcert", &securebootcert_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
+FWTS_REGISTER("securebootcert", &securebootcert_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_TEST_UEFI | FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
