@@ -60,8 +60,8 @@ static char *uefidump_vprintf(char *str, const char *fmt, ...)
 	char buffer[4096];
 
 	va_start(args, fmt);
-
 	vsnprintf(buffer, sizeof(buffer), fmt, args);
+	va_end(args);
 
 	if (str == NULL)
 		str = strdup(buffer);
@@ -72,7 +72,6 @@ static char *uefidump_vprintf(char *str, const char *fmt, ...)
 		strcat(str, buffer);
 	}
 
-	va_end(args);
 	return str;
 }
 
@@ -168,6 +167,7 @@ static char *uefidump_build_dev_path(char *path, fwts_uefi_dev_path *dev_path)
 				else
 					path = uefidump_vprintf(path, "%s,", hidstr);
 			}
+			break;
 		default:
 			path = uefidump_vprintf(path, "\\Unknown-ACPI-DEV-PATH(0x%" PRIx8 ")", dev_path->subtype);
 			break;
@@ -385,8 +385,10 @@ static char *uefidump_build_dev_path(char *path, fwts_uefi_dev_path *dev_path)
 	if (!((dev_path->type & 0x7f) == (FWTS_UEFI_END_DEV_PATH_TYPE) &&
 	      (dev_path->subtype == FWTS_UEFI_END_ENTIRE_DEV_PATH_SUBTYPE))) {
 		uint16_t len = dev_path->length[0] | (((uint16_t)dev_path->length[1])<<8);
-		dev_path = (fwts_uefi_dev_path*)((char *)dev_path + len);
-		path = uefidump_build_dev_path(path, dev_path);
+		if (len > 0) {
+			dev_path = (fwts_uefi_dev_path*)((char *)dev_path + len);
+			path = uefidump_build_dev_path(path, dev_path);
+		}
 	}
 
 	return path;
@@ -654,6 +656,80 @@ static void uefidump_info_signature_support(fwts_framework *fw, fwts_uefi_var *v
 	}
 }
 
+static void uefidump_info_hwerrrec_support(fwts_framework *fw, fwts_uefi_var *var)
+{
+	if (var->datalen != 2) {
+		/* Should be 2 byte, of not, dump it out as a hex dump */
+		uefidump_var_hexdump(fw, var);
+	} else {
+		char *support;
+		uint16_t *value = (uint16_t *)var->data;
+
+		switch (*value) {
+		case 0:
+			support = " (Not support for Hardware Error Record Persistence)";
+			break;
+		case 1:
+			support = " (Support for Hardware Error Record Persistence)";
+			break;
+		default:
+			support = " (reserved value)";
+			break;
+		}
+		fwts_log_info_verbatum(fw, "  Value: 0x%4.4" PRIx16 "%s.", *value, support);
+	}
+}
+
+static void uefidump_info_osindications_supported(fwts_framework *fw, fwts_uefi_var *var)
+{
+	if (var->datalen != 8) {
+		/* Should be 8 bytes, of not, dump it out as a hex dump */
+		uefidump_var_hexdump(fw, var);
+	} else {
+		uint64_t value;
+		char str[300];
+
+		memcpy(&value, var->data, sizeof(uint64_t));
+		*str = 0;
+
+		if (value & EFI_OS_INDICATIONS_BOOT_TO_FW_UI)
+			strcat(str, "EFI_OS_INDICATIONS_BOOT_TO_FW_UI");
+
+		if (value & EFI_OS_INDICATIONS_TIMESTAMP_REVOCATION) {
+			if (*str)
+				strcat(str, ",");
+			strcat(str, "EFI_OS_INDICATIONS_TIMESTAMP_REVOCATION");
+		}
+
+		if (value & EFI_OS_INDICATIONS_FILE_CAPSULE_DELIVERY_SUPPORTED) {
+			if (*str)
+				strcat(str, ",");
+			strcat(str, "EFI_OS_INDICATIONS_FILE_CAPSULE_DELIVERY_SUPPORTED");
+		}
+
+		if (value & EFI_OS_INDICATIONS_FMP_CAPSULE_SUPPORTED) {
+			if (*str)
+				strcat(str, ",");
+			strcat(str, "EFI_OS_INDICATIONS_FMP_CAPSULE_SUPPORTED");
+		}
+
+		if (value & EFI_OS_INDICATIONS_CAPSULE_RESULT_VAR_SUPPORTED) {
+			if (*str)
+				strcat(str, ",");
+			strcat(str, "EFI_OS_INDICATIONS_CAPSULE_RESULT_VAR_SUPPORTED");
+		}
+
+		fwts_log_info_verbatum(fw, "  Value: 0x%16.16" PRIx64 " (%s).", value, str);
+	}
+}
+
+static void uefidump_info_vendor_keys(fwts_framework *fw, fwts_uefi_var *var)
+{
+	uint8_t value = (uint8_t)var->data[0];
+
+	fwts_log_info_verbatum(fw, "  Value: 0x%2.2" PRIx8 ".", value);
+}
+
 static uefidump_info uefidump_info_table[] = {
 	{ "PlatformLangCodes",	uefidump_info_platform_langcodes },
 	{ "PlatformLang",	uefidump_info_platform_lang },
@@ -678,6 +754,9 @@ static uefidump_info uefidump_info_table[] = {
 	{ "MemoryOverwriteRequestControl",	uefidump_info_morc },
 	{ "AcpiGlobalVariable",	uefidump_info_acpi_global_variable },
 	{ "SignatureSupport",	uefidump_info_signature_support },
+	{ "HwErrRecSupport",	uefidump_info_hwerrrec_support },
+	{ "OsIndicationsSupported",	uefidump_info_osindications_supported },
+	{ "VendorKeys",		uefidump_info_vendor_keys },
 	{ NULL, NULL }
 };
 
